@@ -14,23 +14,24 @@ namespace BBSLIST
     // メインビュー
     class BBSListViewMain : public BBSListViewBase
     {
-        bool m_load_etc;
-
       public:
         BBSListViewMain( const std::string& url, const std::string& arg1 = std::string() , const std::string& arg2 = std::string() );
         virtual ~BBSListViewMain();
 
-        virtual void shutdown();
-
         virtual void show_view();
         virtual void update_view();
-        virtual void update_item( const std::string& );
+        virtual void delete_view();
 
       protected:
 
+        // xml保存
+        virtual void save_xml();
+
         virtual Gtk::Menu* get_popupmenu( const std::string& url );
 
-        void save_xml( const std::string& file );
+      private:
+
+        virtual void delete_view_impl();
     };
 };
 
