@@ -156,7 +156,7 @@ namespace BBSLIST
         void edit_tree();
 
         // xml保存
-        virtual void save_xml( const bool backup ) = 0;
+        virtual void save_xml() = 0;
 
         // remove_dir != empty()の時はその名前のディレクトリを削除する
         void save_xml_impl( const std::string& file, const std::string& root, const std::string& remove_dir );
@@ -173,6 +173,8 @@ namespace BBSLIST
         // SKELETON::View の関数のオーバロード
         //
 
+        virtual void save_session();
+
         // 親ウィンドウをセット
         virtual void set_parent_win( Gtk::Window* parent_win );
 
@@ -183,8 +185,6 @@ namespace BBSLIST
                                         const std::string& arg2 = std::string()
             );
 
-        virtual void shutdown();
-
         virtual void clock_in();
 
         // キーを押した
@@ -245,6 +245,8 @@ namespace BBSLIST
         void row_down();
         void page_up();
         void page_down();
+        void prev_dir();
+        void next_dir();
         void expand_all_dir( Gtk::TreeModel::Path path );
 
         // ディレクトリ以下を更新チェック
@@ -262,6 +264,7 @@ namespace BBSLIST
 
         void slot_open_tab();
         void slot_open_browser();
+        void slot_open_cache_browser();
         void slot_append_favorite();
         void slot_newdir();
         void slot_newcomment();
@@ -285,6 +288,7 @@ namespace BBSLIST
         void slot_row_col( const Gtk::TreeModel::iterator& it, const Gtk::TreeModel::Path& path );        
         void slot_checkupdate_selected_rows();
         void slot_checkupdate_open_selected_rows();
+        void slot_sort( const int mode );
 
         virtual void delete_view_impl();
 
