@@ -8,11 +8,9 @@
 
 #include "skeleton/admin.h"
 
-#include <string>
+#include "sign.h"
 
-#define ARTICLE_SIGN "_ARTICLE_"
-#define NEXT_SIGN "_NEXT_"
-#define TIME_SIGN "_TIME_"
+#include <string>
 
 namespace BOARD
 {
@@ -26,6 +24,8 @@ namespace BOARD
         BoardAdmin( const std::string& url );
         ~BoardAdmin();
 
+        virtual void save_session();
+
       protected:
 
         virtual COMMAND_ARGS get_open_list_args( const std::string& url, const COMMAND_ARGS& command_list );
@@ -34,11 +34,14 @@ namespace BOARD
         // ツールバー
         virtual void show_toolbar();
         virtual void toggle_toolbar();
+        virtual void open_searchbar();
+        virtual void close_searchbar();
 
         virtual void command_local( const COMMAND_ARGS& command );
 
         virtual void restore( const bool only_locked );
         virtual COMMAND_ARGS url_to_openarg( const std::string& url, const bool tab, const bool lock );
+        virtual const std::string command_to_url( const COMMAND_ARGS& command );
 
         virtual void switch_admin();
 
