@@ -45,6 +45,7 @@ std::string get_default_font()
     IS_DEFAULT_FONT( "IPAMonaPGothic" );
     IS_DEFAULT_FONT( "Mona-VLGothic" );
     IS_DEFAULT_FONT( "Mona" );
+    IS_DEFAULT_FONT( "Konatu" );
     IS_DEFAULT_FONT( "VL Pゴシック" );
     IS_DEFAULT_FONT( "VL PGothic" );
     IS_DEFAULT_FONT( "さざなみゴシック" );
@@ -153,7 +154,8 @@ const bool ConfigItems::load( const bool restore )
     x_2ch_ua = cf.get_option_str( "x_2ch_ua", CONF_X_2CH_UA );
 
     // ローダのバッファサイズ
-    loader_bufsize = cf.get_option_int( "loader_bufsize", CONF_LOADER_BUFSIZE, 8, 4096 );
+    loader_bufsize = cf.get_option_int( "loader_bufsize", CONF_LOADER_BUFSIZE, 1, 4096 ); // 一般
+    loader_bufsize_board = cf.get_option_int( "loader_bufsize_board", CONF_LOADER_BUFSIZE_BOARD, 1, 4096 ); // スレ一覧用
 
     // ローダのタイムアウト値
     loader_timeout = cf.get_option_int( "loader_timeout", CONF_LOADER_TIMEOUT, 1, 120 );
@@ -164,6 +166,9 @@ const bool ConfigItems::load( const bool restore )
     // ipv6使用
     use_ipv6 = cf.get_option_bool( "use_ipv6", CONF_USE_IPV6 );
 
+    // 同一ホストに対する最大コネクション数( 1 または 2 )
+    connection_num = cf.get_option_int( "connection_num", CONF_CONNECTION_NUM, 1, 2 );
+
     // ブラウザ設定ダイアログのコンボボックスの番号
     browsercombo_id = cf.get_option_int( "browsercombo_id", CONF_BROWSER_NO, 0, CORE::get_browser_number() -1 );
 
@@ -200,6 +205,13 @@ const bool ConfigItems::load( const bool restore )
     // ssspアイコン表示
     show_ssspicon = cf.get_option_bool( "show_ssspicon", CONF_SHOW_SSSPICON );
 
+    // インライン画像の最大幅と高さ
+    embimg_width = cf.get_option_int( "embimg_width", CONF_EMBIMG_WIDTH, 16, 8192 );
+    embimg_height = cf.get_option_int( "embimg_height", CONF_EMBIMG_HEIGHT, 16, 8192 );
+
+    // 画像ビューでdeleteを押したときに確認ダイアログを表示する
+    show_delimgdiag = cf.get_option_bool( "show_delimgdiag", CONF_SHOW_DELIMGDIAG );
+
     // 画像にモザイクをかける
     use_mosaic = cf.get_option_bool( "use_mosaic", CONF_USE_MOSAIC );
 
@@ -221,6 +233,9 @@ const bool ConfigItems::load( const bool restore )
     // 画像の最大サイズ(Mピクセル)
     max_img_pixel = cf.get_option_int( "max_img_pixel", CONF_MAX_IMG_PIXEL, 1, 1024 );
 
+    // 画像のメモリキャッシュ枚数
+    imgcache_size = cf.get_option_int( "imgcache_size", CONF_IMGCACHE_SIZE, 0, 20 );
+
     // JD ホームページのアドレス
     url_jdhp = cf.get_option_str( "url_jdhp", CONF_URL_JDHP );
 
@@ -257,12 +272,27 @@ const bool ConfigItems::load( const bool restore )
     // ツリービューでgtkrcの設定を使用するか
     use_tree_gtkrc = cf.get_option_bool( "use_tree_gtkrc", CONF_USE_TREE_GTKRC );
 
+    // スレビューの選択色でgtkrcの設定を使用するか
+    use_select_gtkrc = cf.get_option_bool( "use_select_gtkrc", CONF_USE_SELECT_GTKRC );
+
     // ツリービューの行間スペース
     tree_ypad = cf.get_option_int( "tree_ypad", CONF_TREE_YPAD, 0, 64 );
 
+    // ツリービューにエクスパンダを表示
+    tree_show_expanders = cf.get_option_bool( "tree_show_expanders", CONF_TREE_SHOW_EXPANDERS );
+
+    // ツリービューのレベルインデント調整量(ピクセル)
+    tree_level_indent = cf.get_option_int( "tree_level_indent", CONF_TREE_LEVEL_INDENT, -256, 256 );
+
+    // カテゴリを開いたときにツリービューをスクロールする
+    scroll_tree = cf.get_option_bool( "scroll_tree", CONF_SCROLL_TREE );
+
     // 各ビューと枠との間の余白
     view_margin = cf.get_option_int( "view_margin", CONF_VIEW_MARGIN, 0, 64 );
 
+    // スクロールバーを左に配置
+    left_scrbar = cf.get_option_bool( "left_scrbar", CONF_LEFT_SCRBAR );
+
     // スレ一覧で古いスレも表示
     show_oldarticle = cf.get_option_bool( "show_oldarticle", CONF_SHOW_OLDARTICLE );
 
@@ -275,6 +305,12 @@ const bool ConfigItems::load( const bool restore )
     // スレ一覧でdeleteを押したときに確認ダイアログを表示する
     show_deldiag = cf.get_option_bool( "show_deldiag", CONF_SHOW_DELDIAG );
 
+    // スレ一覧をロードする前にキャッシュにある一覧を表示
+    show_cached_board = cf.get_option_bool( "show_cached_board", CONF_SHOW_CACHED_BOARD );
+
+    // スレ一覧でお知らせスレ(924)のアイコンを表示する
+    show_924 = cf.get_option_bool( "show_924", CONF_SHOW_924 );
+ 
     // ツリービューのスクロール量(行数)
     tree_scroll_size = cf.get_option_int( "tree_scroll_size", CONF_TREE_SCROLL_SIZE, 1, 64 );
 
@@ -297,7 +333,7 @@ const bool ConfigItems::load( const bool restore )
     live_mode = cf.get_option_int( "live_mode", LIVE_SCRMODE_VARIABLE, 0, LIVE_SCRMODE_NUM -1 );
 
     // 実況速度
-    live_speed = cf.get_option_int( "live_speed", CONF_LIVE_SPEED, 1, 1024 );
+    live_speed = cf.get_option_int( "live_speed", CONF_LIVE_SPEED, 0, 50 );
 
     // 実況のスクロールモードを切り替えるしきい値
     live_threshold = cf.get_option_int( "live_threshold", CONF_LIVE_THRESHOLD, 1, 1024 );
@@ -323,18 +359,40 @@ const bool ConfigItems::load( const bool restore )
     // 「書き込み中」のダイアログを表示しない
     hide_writing_dialog = cf.get_option_bool( "hide_writing_dialog", CONF_HIDE_WRITING_DIALOG );
 
+    // 編集中のメッセージの保存確認ダイアログを表示する
+    show_savemsgdiag = cf.get_option_bool( "show_savemsgdiag", CONF_SHOW_SAVEMSGDIAG );
+
+    // 書き込みビューでテキストを折り返す
+    message_wrap = cf.get_option_bool( "message_wrap", CONF_MESSAGE_WRAP );
+
     // 非アクティブ時に書き込みビューを折りたたむ
     fold_message = cf.get_option_bool( "fold_message", CONF_FOLD_MESSAGE );
 
+    // 非アクティブ時に画像ビューを折りたたむ
+    fold_image = cf.get_option_bool( "fold_image", CONF_FOLD_IMAGE );
+
+    // 書き込み欄の日本語のON/OFF状態を保存
+    keep_im_status = cf.get_option_bool( "keep_im_status", CONF_KEEP_IM_STATUS );
+
     // ポップアップとカーソルの間のマージン
-    margin_popup = cf.get_option_int( "margin_popup", CONF_MARGIN_POPUP, 1, 1024 );
+    margin_popup = cf.get_option_int( "margin_popup", CONF_MARGIN_POPUP, 0, 1024 );
 
     // 画像ポップアップとカーソルの間のマージン
-    margin_imgpopup = cf.get_option_int( "margin_imgpopup", CONF_MARGIN_IMGPOPUP, 1, 1024 );
+    margin_imgpopup_x = cf.get_option_int( "margin_imgpopup_x", CONF_MARGIN_IMGPOPUP_X, 0, 1024 );
+    margin_imgpopup = cf.get_option_int( "margin_imgpopup", CONF_MARGIN_IMGPOPUP, 0, 1024 );
+
+    // ポップアップが消えるまでの時間(ミリ秒)
+    hide_popup_msec = cf.get_option_int( "hide_popup_msec", CONF_HIDE_POPUP_MSEC, 0, 2000 );
+
+    // マウスジェスチャを有効
+    enable_mg = cf.get_option_bool( "enable_mg", CONF_ENABLE_MG );
 
     // マウスジェスチャの判定開始半径
     mouse_radius = cf.get_option_int( "mouse_radius", CONF_MOUSE_RADIUS, 4, 1024 );
 
+    // 数字入力ジャンプの待ち時間(ミリ秒)
+    numberjmp_msec = cf.get_option_int( "numberjmp_msec", CONF_NUMBERJMP_MSEC, 1, 5000 );
+
     // 履歴メニューの表示数
     history_size = cf.get_option_int( "history_size", CONF_HISTORY_SIZE, 0, 256 );
 
@@ -413,6 +471,9 @@ const bool ConfigItems::load( const bool restore )
     str_tmp = cf.get_option_str( "aboneregexthread", "" );
     if( ! str_tmp.empty() ) list_abone_regex_thread = MISC::strtolist( str_tmp );
 
+    // dat落ちしたスレをNGスレタイトルリストから取り除くか( 0: ダイアログ表示 1: 取り除く 2: 除かない )
+    remove_old_abone_thread = cf.get_option_int( "remove_old_abone_thread", CONF_REMOVE_OLD_ABONE_THREAD, 0, 2 );
+
     // スレ あぼーん( レス数 )
     abone_number_thread = cf.get_option_int( "abone_number_thread", CONF_ABONE_NUMBER_THREAD, 0, 9999 );
 
@@ -441,11 +502,14 @@ const bool ConfigItems::load( const bool restore )
     // 3ペーン時にスレ一覧やスレビューを最大化する
     expand_rpane = cf.get_option_bool( "expand_rpane", CONF_EXPAND_RPANE );
 
+    // ペーンの境界をクリックしてサイドバーを開け閉めする
+    open_sidebar_by_click = cf.get_option_bool( "open_sidebar_by_click", CONF_OPEN_SIDEBAR_BY_CLICK );
+
     // 次スレ検索の類似度のしきい値
     threshold_next = cf.get_option_int( "threshold_next", CONF_THRESHOLD_NEXT, 1, 10 );
 
     // 次スレを開いたときにお気に入りのアドレスと名前を自動更新
-    replace_favorite_next = cf.get_option_bool( "replace_favorite_next", CONF_REPLACE_FAVORITE_NEXT );
+    replace_favorite_next = cf.get_option_int( "replace_favorite_next", CONF_REPLACE_FAVORITE_NEXT, 0, 2 );
 
     // お気に入りの自動更新をするかダイアログを出す
     show_diag_replace_favorite = cf.get_option_bool( "show_diag_replace_favorite", CONF_SHOW_DIAG_REPLACE_FAVORITE );
@@ -456,12 +520,36 @@ const bool ConfigItems::load( const bool restore )
     // お気に入りの更新チェック時に板の更新もチェックする
     check_update_board  = cf.get_option_bool( "check_update_board", CONF_CHECK_UPDATE_BOARD );
 
+    // 起動時にお気に入りを自動でチェックする
+    check_update_boot = cf.get_option_bool( "check_update_boot", CONF_CHECK_UPDATE_BOOT );
+
+    // お気に入り登録時に重複項目を登録するか ( 0: 登録する 1: ダイアログ表示  2: 登録しない )
+    check_favorite_dup = cf.get_option_int( "check_favorite_dup", CONF_CHECK_FAVORITE_DUP, 0, 2 );
+
+    // お気に入り登録時に挿入先ダイアログを表示する ( 0 : 表示する 1: 表示せず先頭に追加 2: 表示せず最後に追加 )
+    show_favorite_select_diag = cf.get_option_int( "show_favorite_select_diag", CONF_SHOW_FAVORITE_SELECT_DIAG, 0, 2 );
+
     // Ctrl+qでウィンドウを閉じない
     disable_close = cf.get_option_bool( "disable_close", CONF_DISABLE_CLOSE );
 
+    // メニューバーを非表示にした時にダイアログを表示
+    show_hide_menubar_diag = cf.get_option_bool( "show_hide_menubar_diag", CONF_SHOW_HIDE_MENUBAR_DIAG );
+
     // まちBBSの取得に offlaw.cgi を使用する
     use_machi_offlaw = cf.get_option_bool( "use_machi_offlaw", CONF_USE_MACHI_OFFLAW );
 
+    // 書き込み履歴のあるスレを削除する時にダイアログを表示
+    show_del_written_thread_diag = cf.get_option_bool( "show_del_written_thread_diag", CONF_SHOW_DEL_WRITTEN_THREAD_DIAG );
+
+    // スレを削除する時に画像キャッシュも削除する ( 0: ダイアログ表示 1: 削除 2: 削除しない )
+    delete_img_in_thread = cf.get_option_int( "delete_img_in_thread", CONF_DELETE_IMG_IN_THREAD, 0, 2 );
+
+    // FIFOの作成などにエラーがあったらダイアログを表示する
+    show_diag_fifo_error = cf.get_option_bool( "show_diag_fifo_error", CONF_SHOW_DIAG_FIFO_ERROR );
+
+    // 指定した分ごとにセッションを自動保存 (0: 保存しない)
+    save_session = cf.get_option_int( "save_session", CONF_SAVE_SESSION, 0, (24*60) );
+
 #ifdef HAVE_MIGEMO_H
     // migemo-dictの場所
     migemodict_path = cf.get_option_str( "migemodict_path", CONF_MIGEMO_PATH );
@@ -478,7 +566,7 @@ const bool ConfigItems::load( const bool restore )
         // 非resotreモードでバックアップが存在する
         if( ! restore && CACHE::file_exists( CACHE::path_conf_bkup() ) == CACHE::EXIST_FILE )
         {
-            msg = path_conf + "に異常な値があります。全設定をバックアップから復元しますか？";
+            msg = "設定ファイル (" + path_conf + ")に異常な値があります。全設定をバックアップから復元しますか？";
             mdiag = new Gtk::MessageDialog( msg, false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_YES_NO );
             int ret = mdiag->run();
             delete mdiag;
@@ -486,14 +574,14 @@ const bool ConfigItems::load( const bool restore )
         }
         else
         {
-            msg = path_conf + "に異常な値があるため、一部をデフォルトに設定しました。";
+            msg = "設定ファイル (" + path_conf + ")に異常な値があるため、一部をデフォルトに設定しました。";
             mdiag = new Gtk::MessageDialog( msg );
             mdiag->run();
             delete mdiag;
         }
     }
     // 正常ならバックアップ
-    else
+    else if( CACHE::file_exists( CACHE::path_root() ) == CACHE::EXIST_DIR )
     {
         save_impl( CACHE::path_conf_bkup() );
     }
@@ -575,12 +663,15 @@ void ConfigItems::save_impl( const std::string& path )
     cf.update( "x_2ch_ua", x_2ch_ua );
 
     cf.update( "loader_bufsize", loader_bufsize );
+    cf.update( "loader_bufsize_board", loader_bufsize_board );
+
     cf.update( "loader_timeout", loader_timeout );
     cf.update( "loader_timeout_post", loader_timeout_post );
     cf.update( "loader_timeout_img", loader_timeout_img );
     cf.update( "loader_timeout_checkupdate", loader_timeout_checkupdate );
 
     cf.update( "use_ipv6", use_ipv6 );
+    cf.update( "connection_num", connection_num );
 
     cf.update( "command_openurl", command_openurl );
     cf.update( "browsercombo_id", browsercombo_id );
@@ -598,6 +689,9 @@ void ConfigItems::save_impl( const std::string& path )
     cf.update( "use_image_view", use_image_view );
     cf.update( "use_inline_image", use_inline_image );
     cf.update( "show_ssspicon", show_ssspicon );
+    cf.update( "embimg_width", embimg_width );
+    cf.update( "embimg_height", embimg_height );
+    cf.update( "show_delimgdiag", show_delimgdiag );
     cf.update( "use_mosaic", use_mosaic );
     cf.update( "mosaic_size", mosaic_size );
     cf.update( "zoom_to_fit", zoom_to_fit );
@@ -605,6 +699,7 @@ void ConfigItems::save_impl( const std::string& path )
     cf.update( "del_imgabone_day", del_imgabone_day );
     cf.update( "max_img_size", max_img_size );
     cf.update( "max_img_pixel", max_img_pixel );
+    cf.update( "imgcache_size", imgcache_size );
 
     cf.update( "cl_char", str_color[ COLOR_CHAR ] );
     cf.update( "cl_char_name", str_color[ COLOR_CHAR_NAME ] );
@@ -641,15 +736,24 @@ void ConfigItems::save_impl( const std::string& path )
     cf.update( "cl_back_board_even", str_color[ COLOR_BACK_BOARD_EVEN ] );
 
     cf.update( "use_tree_gtkrc", use_tree_gtkrc );
+    cf.update( "use_select_gtkrc", use_select_gtkrc );
 
     cf.update( "tree_ypad", tree_ypad );
+    cf.update( "tree_show_expanders", tree_show_expanders );
+    cf.update( "tree_level_indent", tree_level_indent );
+
+    cf.update( "scroll_tree", scroll_tree );
 
     cf.update( "view_margin", view_margin );
 
+    cf.update( "left_scrbar", left_scrbar );
+
     cf.update( "show_oldarticle", show_oldarticle );
     cf.update( "newthread_hour", newthread_hour );
     cf.update( "inc_search_board", inc_search_board );
     cf.update( "show_deldiag", show_deldiag );
+    cf.update( "show_cached_board", show_cached_board );
+    cf.update( "show_924", show_924 );
 
     cf.update( "tree_scroll_size", tree_scroll_size );
     cf.update( "scroll_size", scroll_size );
@@ -669,10 +773,18 @@ void ConfigItems::save_impl( const std::string& path )
     cf.update( "maxsize_postlog", maxsize_postlog );
     cf.update( "save_posthist", save_posthist );
     cf.update( "hide_writing_dialog", hide_writing_dialog );
+    cf.update( "show_savemsgdiag", show_savemsgdiag );
+    cf.update( "message_wrap", message_wrap );
     cf.update( "fold_message", fold_message );
+    cf.update( "fold_image", fold_image );
+    cf.update( "keep_im_status", keep_im_status );
     cf.update( "margin_popup", margin_popup );
+    cf.update( "margin_imgpopup_x", margin_imgpopup_x );
     cf.update( "margin_imgpopup", margin_imgpopup );
+    cf.update( "hide_popup_msec", hide_popup_msec );
+    cf.update( "enable_mg", enable_mg );
     cf.update( "mouse_radius", mouse_radius );
+    cf.update( "numberjmp_msec", numberjmp_msec );
     cf.update( "history_size", history_size );
     cf.update( "historyview_size", historyview_size );
     cf.update( "aahistory_size", aahistory_size );
@@ -713,6 +825,8 @@ void ConfigItems::save_impl( const std::string& path )
     cf.update( "abonewordthread", str_abone_word_thread );
     cf.update( "aboneregexthread", str_abone_regex_thread );
 
+    cf.update( "remove_old_abone_thread", remove_old_abone_thread );
+
     cf.update( "abone_number_thread", abone_number_thread );
     cf.update( "abone_hour_thread", abone_hour_thread );
 
@@ -731,13 +845,23 @@ void ConfigItems::save_impl( const std::string& path )
     cf.update( "expand_sidebar", expand_sidebar );
     cf.update( "expand_rpane", expand_rpane );
 
+    cf.update( "open_sidebar_by_click", open_sidebar_by_click );
+
     cf.update( "threshold_next", threshold_next );
     cf.update( "replace_favorite_next", replace_favorite_next );
     cf.update( "show_diag_replace_favorite", show_diag_replace_favorite );
     cf.update( "bookmark_drop", bookmark_drop );
     cf.update( "check_update_board", check_update_board );
+    cf.update( "check_update_boot", check_update_boot );
+    cf.update( "check_favorite_dup", check_favorite_dup );
+    cf.update( "show_favorite_select_diag", show_favorite_select_diag );
     cf.update( "disable_close", disable_close );
+    cf.update( "show_hide_menubar_diag", show_hide_menubar_diag );
     cf.update( "use_machi_offlaw", use_machi_offlaw );
+    cf.update( "show_del_written_thread_diag", show_del_written_thread_diag );
+    cf.update( "delete_img_in_thread", delete_img_in_thread );
+    cf.update( "show_diag_fifo_error", show_diag_fifo_error );
+    cf.update( "save_session", save_session );
 
 #ifdef HAVE_MIGEMO_H
     cf.update( "migemodict_path", migemodict_path );
@@ -919,7 +1043,13 @@ void ConfigItems::set_proxy_for2ch( const std::string& proxy )
 
     // basic認証
     JDLIB::Regex regex;
-    if( regex.exec( "([^/]+:[^/]+@)(.+)$" , proxy ) )
+    const size_t offset = 0;
+    const bool icase = false;
+    const bool newline = true;
+    const bool usemigemo = false;
+    const bool wchar = false;
+
+    if( regex.exec( "([^/]+:[^/]+@)(.+)$" , proxy, offset, icase, newline, usemigemo, wchar ) )
     {
         proxy_basicauth_for2ch = regex.str( 1 ).substr( 0, regex.str( 1 ).length() - 1 );
         proxy_for2ch = regex.str( 2 );
@@ -934,7 +1064,13 @@ void ConfigItems::set_proxy_for2ch_w( const std::string& proxy )
 
     // basic認証
     JDLIB::Regex regex;
-    if( regex.exec( "([^/]+:[^/]+@)(.+)$" , proxy ) )
+    const size_t offset = 0;
+    const bool icase = false;
+    const bool newline = true;
+    const bool usemigemo = false;
+    const bool wchar = false;
+
+    if( regex.exec( "([^/]+:[^/]+@)(.+)$" , proxy, offset, icase, newline, usemigemo, wchar ) )
     {
         proxy_basicauth_for2ch_w = regex.str( 1 ).substr( 0, regex.str( 1 ).length() - 1 );
         proxy_for2ch_w = regex.str( 2 );
@@ -949,7 +1085,13 @@ void ConfigItems::set_proxy_for_data( const std::string& proxy )
 
     // basic認証
     JDLIB::Regex regex;
-    if( regex.exec( "([^/]+:[^/]+@)(.+)$" , proxy ) )
+    const size_t offset = 0;
+    const bool icase = false;
+    const bool newline = true;
+    const bool usemigemo = false;
+    const bool wchar = false;
+
+    if( regex.exec( "([^/]+:[^/]+@)(.+)$" , proxy, offset, icase, newline, usemigemo, wchar ) )
     {
         proxy_basicauth_for_data = regex.str( 1 ).substr( 0, regex.str( 1 ).length() - 1 );
         proxy_for_data = regex.str( 2 );
