@@ -87,6 +87,9 @@ namespace CONFIG
         // ipv6使用
         bool use_ipv6;
 
+        // 同一ホストに対する最大コネクション数( 1 または 2 )
+        int connection_num;
+
         // リンクをクリックしたときに実行するコマンド
         std::string command_openurl;
 
@@ -123,6 +126,13 @@ namespace CONFIG
         // ssspアイコン表示
         bool show_ssspicon;
 
+        // インライン画像の最大幅と高さ
+        int embimg_width;
+        int embimg_height;
+
+        // 画像ビューでdeleteを押したときに確認ダイアログを表示する
+        bool show_delimgdiag;
+
         // 画像にモザイクかける
         bool use_mosaic;
 
@@ -194,13 +204,22 @@ namespace CONFIG
         // ツリービューの行間スペース
         int tree_ypad;
 
+        // ツリービューにエクスパンダを表示
+        bool tree_show_expanders;
+
+        // ツリービューのレベルインデント調整量(ピクセル)
+        int tree_level_indent;
+
         // カテゴリを開いたときにツリービューをスクロールする
         bool scroll_tree;
 
         // 各ビューと枠との間の余白
         int view_margin;
 
-        // スレ一覧で古いスレも表示
+        // スクロールバーを左に配置
+        bool left_scrbar;
+
+        // スレ一覧で古いスレも表示 	 
         bool show_oldarticle;
 
         // スレ一覧で指定した値(時間)よりも後に立てられたスレを新着とみなす
@@ -266,9 +285,18 @@ namespace CONFIG
         // 「書き込み中」のダイアログを表示しない
         bool hide_writing_dialog;
 
+        // 編集中のメッセージの保存確認ダイアログを表示する
+        bool show_savemsgdiag;
+
+        // 書き込みビューでテキストを折り返す
+        bool message_wrap;
+
         // 非アクティブ時に書き込みビューを折りたたむ
         bool fold_message;
 
+        // 非アクティブ時に画像ビューを折りたたむ
+        bool fold_image;
+
         // 書き込み欄の日本語のON/OFF状態を保存
         bool keep_im_status;
 
@@ -276,11 +304,21 @@ namespace CONFIG
         int margin_popup;
 
         // 画像ポップアップとカーソルの間のマージン
-        int margin_imgpopup;
+        int margin_imgpopup_x;  // 水平方向
+        int margin_imgpopup; // 垂直方向
+
+        // ポップアップが消えるまでの時間(ミリ秒)
+        int hide_popup_msec;
+
+        // マウスジェスチャを有効
+        bool enable_mg;
 
         // マウスジェスチャの判定開始半径
         int mouse_radius;
 
+        // 数字入力ジャンプの待ち時間(ミリ秒)
+        int numberjmp_msec;
+
         // 履歴メニューの表示数
         int history_size;
 
@@ -382,6 +420,9 @@ namespace CONFIG
         // 3ペーン時にスレ一覧やスレビューを最大化するか
         bool expand_rpane;
 
+        // ペーンの境界をクリックしてサイドバーを開け閉めする
+        bool open_sidebar_by_click;
+
         // 次スレ検索の類似度のしきい値
         int threshold_next;
 
@@ -400,18 +441,33 @@ namespace CONFIG
         // 起動時にお気に入りを自動でチェックする
         bool check_update_boot;
 
+        // お気に入り登録時に重複項目を登録するか ( 0: 登録する 1: ダイアログ表示  2: 登録しない )
+        int check_favorite_dup;
+
+        // お気に入り登録時に挿入先ダイアログを表示する ( 0 : 表示する 1: 表示せず先頭に追加 2: 表示せず最後に追加 )
+        int show_favorite_select_diag;
+
         // Ctrl+qでウィンドウを閉じない
         bool disable_close;
 
+        // メニューバーを非表示にした時にダイアログを表示
+        bool show_hide_menubar_diag;
+
         // まちBBSの取得に offlaw.cgi を使用する
         bool use_machi_offlaw;
 
         // 書き込み履歴のあるスレを削除する時にダイアログを表示
         bool show_del_written_thread_diag;
 
+        // スレを削除する時に画像キャッシュも削除する ( 0: ダイアログ表示 1: 削除 2: 削除しない )
+        int delete_img_in_thread;
+
         // FIFOの作成などにエラーがあったらダイアログを表示する
         bool show_diag_fifo_error;
 
+        // 指定した分ごとにセッションを自動保存 (0: 保存しない)
+        int save_session;
+        
 #ifdef HAVE_MIGEMO_H
         // migemo-dictの場所
         std::string migemodict_path;
