@@ -47,6 +47,23 @@ namespace CONTROL
 
         TabRight,
         TabLeft,
+        TabRightUpdated,
+        TabLeftUpdated,
+
+        TabNum1,
+        TabNum2,
+        TabNum3,
+        TabNum4,
+        TabNum5,
+        TabNum6,
+        TabNum7,
+        TabNum8,
+        TabNum9,
+
+        CloseAllTabs,
+        CloseOtherTabs,
+
+        CheckUpdateTabs,
 
         PreBookMark,
         NextBookMark,
@@ -59,11 +76,15 @@ namespace CONTROL
         ShowPopupMenu,
 
         ShowMenuBar,
+        ShowToolBarMain,
         ShowSideBar,
 
         PageUp,
         PageDown,
 
+        PrevDir,
+        NextDir,
+
         Home,
         End,
 
@@ -76,8 +97,10 @@ namespace CONTROL
         Save,
         Delete,
         Reload,
+        ReloadArticle,
         StopLoading,
         Cancel = StopLoading,
+        OpenURL,
         Copy,
         SelectAll,
         AppendFavorite,
@@ -93,6 +116,13 @@ namespace CONTROL
         DrawOutAnd,
         DrawOutOr,
 
+        CheckUpdateRoot,
+        CheckUpdateOpenRoot,
+
+        QuitJD,
+        MaximizeMainWin,
+        IconifyMainWin,
+
         ClickButton, // 以下、マウスボタン専用の設定
         DblClickButton,
         TrpClickButton,
@@ -115,9 +145,6 @@ namespace CONTROL
         OpenBoardButton, // 以下、マウスボタン専用の設定
         OpenBoardTabButton,
 
-        CheckUpdateRoot,
-        CheckUpdateOpenRoot,
-
         BBSLISTMOTION_END,
 
         // BOARD系
@@ -148,6 +175,9 @@ namespace CONTROL
         PrevRes,
         NextRes,
 
+        PrePost,
+        NextPost,
+
         GotoNew,
         OpenParentBoard,
         WriteMessage,
@@ -167,6 +197,7 @@ namespace CONTROL
 
         DrawoutAncButton,
         PopupmenuAncButton,
+        JumpAncButton,
 
         PopupIDButton,
         DrawoutIDButton,
@@ -205,6 +236,8 @@ namespace CONTROL
         CloseImageButton, // 以下、マウスボタン専用の設定
         ScrollImageButton,
         CancelMosaicButton,
+        SaveImageButton,
+        ResizeImageButton,
 
         IMAGEVIEWMOTION_END,
 
