@@ -47,11 +47,15 @@ namespace CONTROL
 #define KEYCONF_ShowPopupMenu  "Shift+F10 Ctrl+m Menu"
 
 #define KEYCONF_ShowMenuBar  "F8"
+#define KEYCONF_ShowToolBarMain  ""
 #define KEYCONF_ShowSideBar  "F9"
 
 #define KEYCONF_PageUp  "Page_Up KP_Prior"
 #define KEYCONF_PageDown  "Page_Down KP_Next"
 
+#define KEYCONF_PrevDir  "{"
+#define KEYCONF_NextDir  "}"
+
 #define KEYCONF_Home  "Home g < KP_Home"
 #define KEYCONF_End  "End G > KP_End"
 
@@ -64,6 +68,7 @@ namespace CONTROL
 #define KEYCONF_Save  "Ctrl+s"
 #define KEYCONF_Delete  "Delete KP_Delete"
 #define KEYCONF_Reload  "F5 s"
+#define KEYCONF_ReloadArticle  "Shift+F5 S"
 #define KEYCONF_StopLoading  "Escape"
 #define KEYCONF_OpenURL "Ctrl+o"
 #define KEYCONF_Copy  "Ctrl+c"
@@ -72,10 +77,13 @@ namespace CONTROL
 
 #define KEYCONF_Search  "Ctrl+f / KP_Divide"
 #define KEYCONF_SearchInvert  "?"
-#define KEYCONF_SearchNext  "Enter F3 Ctrl+g n"
+#define KEYCONF_SearchNext  "Enter F3 Ctrl+g"
 #define KEYCONF_SearchPrev  "Shift+Enter Ctrl+F3 Ctrl+G N"
 #define KEYCONF_DrawOutAnd  "Ctrl+Enter"
 
+#define KEYCONF_CheckUpdateRoot ""
+#define KEYCONF_CheckUpdateOpenRoot ""
+
 // BBSLIST
 #define KEYCONF_OpenBoard  "Space"
 #define KEYCONF_OpenBoardTab  "Ctrl+Space"
@@ -168,19 +176,32 @@ namespace CONTROL
 #define MOUSECONF_TabRightUpdated ""
 #define MOUSECONF_TabLeftUpdated ""
 
+#define MOUSECONF_CloseAllTabs ""
+#define MOUSECONF_CloseOtherTabs ""
+
+#define MOUSECONF_CheckUpdateTabs ""
+
 #define MOUSECONF_ToggleArticle "2"
+#define MOUSECONF_ShowSideBar  ""
+#define MOUSECONF_ShowMenuBar ""
+#define MOUSECONF_ShowToolBarMain ""
 #define MOUSECONF_Home "68"
 #define MOUSECONF_End "62"
 #define MOUSECONF_Quit "26"
 #define MOUSECONF_Reload "82"
 #define MOUSECONF_StopLoading "8"
+#define MOUSECONF_AppendFavorite  ""
+
 #define MOUSECONF_NewArticle "24"
 #define MOUSECONF_WriteMessage "24"
 
-// 全お気に入り更新チェック
 #define MOUSECONF_CheckUpdateRoot "48"
 #define MOUSECONF_CheckUpdateOpenRoot "42"
 
+#define MOUSECONF_QuitJD ""
+#define MOUSECONF_MaximizeMainWin ""
+#define MOUSECONF_IconifyMainWin ""
+
 // ARTICLE
 #define MOUSECONF_GotoNew "626"
 #define MOUSECONF_SearchNextArticle "28"
@@ -253,6 +274,8 @@ namespace CONTROL
 #define BUTTONCONF_CloseImageButton "Mid"
 #define BUTTONCONF_ScrollImageButton "Left"
 #define BUTTONCONF_CancelMosaicButton ""
+#define BUTTONCONF_SaveImageButton ""
+#define BUTTONCONF_ResizeImageButton "Left"
 
 }
 
