@@ -71,11 +71,15 @@ void KeyConfig::load_conf()
     SETKEYMOTION( "ShowPopupMenu", KEYCONF_ShowPopupMenu );
 
     SETKEYMOTION( "ShowMenuBar", KEYCONF_ShowMenuBar );
+    SETKEYMOTION( "ShowToolBarMain", KEYCONF_ShowToolBarMain );
     SETKEYMOTION( "ShowSideBar", KEYCONF_ShowSideBar );
 
     SETKEYMOTION( "PageUp", KEYCONF_PageUp );
     SETKEYMOTION( "PageDown", KEYCONF_PageDown );
 
+    SETKEYMOTION( "PrevDir", KEYCONF_PrevDir );
+    SETKEYMOTION( "NextDir", KEYCONF_NextDir );
+
     SETKEYMOTION( "Home", KEYCONF_Home );
     SETKEYMOTION( "End", KEYCONF_End );
 
@@ -88,6 +92,7 @@ void KeyConfig::load_conf()
     SETKEYMOTION( "Save", KEYCONF_Save );
     SETKEYMOTION( "Delete", KEYCONF_Delete );
     SETKEYMOTION( "Reload", KEYCONF_Reload );
+    SETKEYMOTION( "ReloadArticle", KEYCONF_ReloadArticle );
     SETKEYMOTION( "StopLoading",  KEYCONF_StopLoading ); // = CONTROL::Cancel
     SETKEYMOTION( "OpenURL", KEYCONF_OpenURL );
     SETKEYMOTION( "Copy", KEYCONF_Copy );
@@ -100,6 +105,9 @@ void KeyConfig::load_conf()
     SETKEYMOTION( "SearchPrev", KEYCONF_SearchPrev );
     SETKEYMOTION( "DrawOutAnd", KEYCONF_DrawOutAnd );
 
+    SETMOTION( "CheckUpdateRoot", KEYCONF_CheckUpdateRoot );
+    SETMOTION( "CheckUpdateOpenRoot", KEYCONF_CheckUpdateOpenRoot );
+
     // BBSLIST
     SETKEYMOTION( "OpenBoard", KEYCONF_OpenBoard );
     SETKEYMOTION( "OpenBoardTab", KEYCONF_OpenBoardTab );
@@ -123,6 +131,9 @@ void KeyConfig::load_conf()
     SETKEYMOTION( "PrevRes", KEYCONF_PrevRes );
     SETKEYMOTION( "NextRes", KEYCONF_NextRes );
 
+    SETKEYMOTION( "PrePost", KEYCONF_PrePost );
+    SETKEYMOTION( "NextPost", KEYCONF_NextPost );
+
     SETKEYMOTION( "GotoNew", KEYCONF_GotoNew );
     SETKEYMOTION( "WriteMessage", KEYCONF_WriteMessage );
 
@@ -192,7 +203,13 @@ void KeyConfig::set_one_motion_impl( const int id, const int mode, const std::st
     const bool trpclick = false;
 
     JDLIB::Regex regex;
-    if( regex.exec( "(Ctrl\\+)?(Shift\\+)?(Alt\\+)?(.*)", str_motion, 0, true ) ){
+    const size_t offset = 0;
+    const bool icase = true; // 大文字小文字区別しない
+    const bool newline = true;
+    const bool usemigemo = false;
+    const bool wchar = false;
+
+    if( regex.exec( "(Ctrl\\+)?(Shift\\+)?(Alt\\+)?(.*)", str_motion, offset, icase, newline, usemigemo, wchar ) ){
 
         if( ! regex.str( 1 ).empty() ) ctrl = true;
         if( ! regex.str( 2 ).empty() ) shift = true;
@@ -274,8 +291,18 @@ void KeyConfig::toggle_emacs_mode()
 // タブで開くキーを入れ替えているか
 const bool KeyConfig::is_toggled_tab_key()
 {
-    return ( get_str_motions( CONTROL::OpenArticleTab ).find( "Space" ) != std::string::npos
-             && get_str_motions( CONTROL::OpenArticleTab ).find( "Ctrl+Space" ) == std::string::npos );
+    const bool ret = ( get_str_motions( CONTROL::OpenBoard ).find( "Ctrl+Space" ) != std::string::npos
+                       && get_str_motions( CONTROL::OpenBoardTab ).find( "Space" ) != std::string::npos
+
+                       && get_str_motions( CONTROL::OpenArticle ).find( "Ctrl+Space" ) != std::string::npos
+                       && get_str_motions( CONTROL::OpenArticleTab ).find( "Space" ) != std::string::npos
+        );
+
+#ifdef _DEBUG
+    std::cout << "KeyConfig::is_toggled_tab_key ret = " << ret << std::endl;
+#endif
+
+    return ret;
 }
 
 
@@ -292,6 +319,7 @@ void KeyConfig::toggle_tab_key( const bool toggle )
 
         set_one_motion( "OpenBoard", "Ctrl+Space" );
         set_one_motion( "OpenBoardTab", "Space" );
+
         set_one_motion( "OpenArticle", "Ctrl+Space" );
         set_one_motion( "OpenArticleTab", "Space" );
     }
@@ -299,6 +327,7 @@ void KeyConfig::toggle_tab_key( const bool toggle )
 
         set_one_motion( "OpenBoard", "Space" );
         set_one_motion( "OpenBoardTab", "Ctrl+Space" );
+
         set_one_motion( "OpenArticle", "Space" );
         set_one_motion( "OpenArticleTab", "Ctrl+Space" );
     }
