@@ -41,19 +41,32 @@ void MouseConfig::load_conf()
     SETMOTION( "Left", MOUSECONF_Left );
     SETMOTION( "TabRight", MOUSECONF_TabRight );
     SETMOTION( "TabLeft", MOUSECONF_TabLeft );
+    SETMOTION( "TabRightUpdated", MOUSECONF_TabRightUpdated );
+    SETMOTION( "TabLeftUpdated", MOUSECONF_TabLeftUpdated );
+    SETMOTION( "CloseAllTabs", MOUSECONF_CloseAllTabs );
+    SETMOTION( "CloseOtherTabs", MOUSECONF_CloseOtherTabs );
+    SETMOTION( "CheckUpdateTabs", MOUSECONF_CheckUpdateTabs );
     SETMOTION( "ToggleArticle", MOUSECONF_ToggleArticle );
+    SETMOTION( "ShowSideBar", MOUSECONF_ShowSideBar );
+    SETMOTION( "ShowMenuBar", MOUSECONF_ShowMenuBar );
+    SETMOTION( "ShowToolBarMain", MOUSECONF_ShowToolBarMain );
     SETMOTION( "Home", MOUSECONF_Home );
     SETMOTION( "End", MOUSECONF_End );
     SETMOTION( "Quit", MOUSECONF_Quit );
     SETMOTION( "Reload", MOUSECONF_Reload );
     SETMOTION( "StopLoading", MOUSECONF_StopLoading );
+    SETMOTION( "AppendFavorite", MOUSECONF_AppendFavorite );
+
     SETMOTION( "NewArticle", MOUSECONF_NewArticle );
     SETMOTION( "WriteMessage", MOUSECONF_WriteMessage );
 
-    // 全お気に入り更新チェック
     SETMOTION( "CheckUpdateRoot", MOUSECONF_CheckUpdateRoot );
     SETMOTION( "CheckUpdateOpenRoot", MOUSECONF_CheckUpdateOpenRoot );
 
+    SETMOTION( "QuitJD", MOUSECONF_QuitJD );
+    SETMOTION( "MaximizeMainWin", MOUSECONF_MaximizeMainWin );
+    SETMOTION( "IconifyMainWin", MOUSECONF_IconifyMainWin );
+
     // ARTICLE
     SETMOTION( "GotoNew", MOUSECONF_GotoNew );
     SETMOTION( "SearchNextArticle", MOUSECONF_SearchNextArticle );
