@@ -70,17 +70,26 @@ MousePref::MousePref( Gtk::Window* parent, const std::string& url )
     append_row( CONTROL::TabRightUpdated );
     append_row( CONTROL::TabLeftUpdated );
     append_row( CONTROL::ToggleArticle );
+    append_row( CONTROL::ShowSideBar );
+    append_row( CONTROL::ShowMenuBar );
+    append_row( CONTROL::ShowToolBarMain );
     append_row( CONTROL::Home );
     append_row( CONTROL::End );
     append_row( CONTROL::Quit );
+    append_row( CONTROL::CloseAllTabs );
+    append_row( CONTROL::CloseOtherTabs );
+    append_row( CONTROL::CheckUpdateTabs );
     append_row( CONTROL::Reload );
     append_row( CONTROL::StopLoading );
+    append_row( CONTROL::AppendFavorite );
 
-    append_comment_row( "" );
-    append_comment_row( "■ "+ CONTROL::get_mode_label( CONTROL::MODE_BBSLIST ) );
     append_row( CONTROL::CheckUpdateRoot );
     append_row( CONTROL::CheckUpdateOpenRoot );
 
+    append_row( CONTROL::QuitJD );
+    append_row( CONTROL::MaximizeMainWin );
+    append_row( CONTROL::IconifyMainWin );
+
     append_comment_row( "" );
     append_comment_row( "■ "+ CONTROL::get_mode_label( CONTROL::MODE_BOARD ) );
     append_row( CONTROL::NewArticle );
