@@ -35,9 +35,6 @@
 
 enum
 {
-    MAX_WIDTH_EMB = 100, // 埋め込み画像の最大横幅(ピクセル)
-    MAX_HEIGHT_EMB = 100, // 埋め込み画像の最大横幅(ピクセル)
-
     MAX_REDIRECT = 5  // 最大リダイレクト回数
 };
 
@@ -213,6 +210,7 @@ const int Img::get_height_mosaic()
 const bool Img::is_cached()
 {
     if( is_loading() ) return false;
+    if( is_wait() ) return false;
     if( ! total_length() ) return false;
 
     return ( get_code() == HTTP_OK );
@@ -422,10 +420,9 @@ const bool Img::is_fake()
     if( ! is_cached() ) return false;
 
     bool ret = false;
-    std::string url = m_url;
-    if( ! m_url_alt.empty() ) url = m_url_alt;
 
-    if( DBIMG::get_type_ext( url ) != m_type ) ret = true;
+    if( DBIMG::get_type_ext( m_url ) != m_type ) ret = true;
+    else if( ! m_url_alt.empty() && DBIMG::get_type_ext( m_url_alt ) != m_type ) ret = true;
 
 #ifdef _DEBUG
     std::cout << "Img::is_fake url = " << url << " ret = " << ret << std::endl;
@@ -526,9 +523,9 @@ void Img::receive_finish()
     if( get_code() == HTTP_OK && ! current_length() ) m_type = T_NODATA;
 
     // リダイレクト
-    if( get_code() == HTTP_REDIRECT ){
+    if( get_code() == HTTP_REDIRECT || get_code() == HTTP_MOVED_PERM ){
 #ifdef _DEBUG
-        std::cout << "302 redirect url = " << location() << std::endl;
+        std::cout << "301/302 redirect url = " << location() << std::endl;
 #endif
         // アドレスに "404", ".htm" が含まれていたら not found と仮定
         std::string url_tmp = MISC::tolower_str( location() );
@@ -660,8 +657,8 @@ void Img::set_embedded_size()
 
     // 縮小比率を計算してサイズ取得
     double scale;
-    double scale_w = ( double ) MAX_WIDTH_EMB / m_width;
-    double scale_h = ( double ) MAX_HEIGHT_EMB / m_height;
+    double scale_w = ( double ) CONFIG::get_embimg_width() / m_width;
+    double scale_h = ( double ) CONFIG::get_embimg_height() / m_height;
     scale = MIN( scale_w, scale_h );
     if( scale < 1.0 ){
         m_width_emb = (int)( m_width * scale );
