@@ -5,6 +5,7 @@
 
 #include "board2ch.h"
 #include "article2ch.h"
+#include "articlehash.h"
 
 #include "config/globalconf.h"
 
@@ -14,26 +15,19 @@
 
 #include "login2ch.h"
 #include "loginbe.h"
+#include "loginp2.h"
 
 #include <sstream>
 
 using namespace DBTREE;
 
 
-enum
-{
-    DEFAULT_NUMBER_MAX_2CH = 1000  // 規定の最大レス数
-};
-
-
 Board2ch::Board2ch( const std::string& root, const std::string& path_board, const std::string& name )
     : Board2chCompati( root, path_board, name, std::string() )
 {
 #ifdef _DEBUG
     std::cout << "Board2ch::Board2ch\n";
 #endif
-
-    set_number_max_res( DEFAULT_NUMBER_MAX_2CH );
 }
 
 
@@ -42,11 +36,20 @@ Board2ch::~Board2ch()
 
 
 // ユーザエージェント
+// ダウンロード用
 const std::string& Board2ch::get_agent()
 {
     return CONFIG::get_agent_for2ch();
 }
 
+// 書き込み用
+const std::string& Board2ch::get_agent_w()
+{
+    if( CORE::get_loginp2()->login_now() ) return CONFIG::get_agent_for_data();
+
+    return CONFIG::get_agent_for2ch();
+}
+
 
 // 読み込み用プロキシ
 const std::string Board2ch::get_proxy_host()
@@ -86,6 +89,12 @@ const std::string Board2ch::get_proxy_basicauth()
 // 書き込み用プロキシ
 const std::string Board2ch::get_proxy_host_w()
 {
+    if( CORE::get_loginp2()->login_now() ){
+
+        if( CONFIG::get_use_proxy_for_data() ) return CONFIG::get_proxy_for_data();
+        else return std::string();
+    }
+
     const int mode = get_mode_local_proxy_w();
 
     if( mode == DBTREE::PROXY_GLOBAL ){
@@ -98,6 +107,8 @@ const std::string Board2ch::get_proxy_host_w()
 
 const int Board2ch::get_proxy_port_w()
 {
+    if( CORE::get_loginp2()->login_now() ) return CONFIG::get_proxy_port_for_data();
+
     const int mode = get_mode_local_proxy_w();
 
     if( mode == DBTREE::PROXY_GLOBAL ) return CONFIG::get_proxy_port_for2ch_w();
@@ -109,6 +120,8 @@ const int Board2ch::get_proxy_port_w()
 
 const std::string Board2ch::get_proxy_basicauth_w()
 {
+    if( CORE::get_loginp2()->login_now() ) return CONFIG::get_proxy_basicauth_for_data();
+
     const int mode = get_mode_local_proxy_w();
 
     if( mode == DBTREE::PROXY_GLOBAL ) return CONFIG::get_proxy_basicauth_for2ch_w();
@@ -127,8 +140,15 @@ const std::string Board2ch::cookie_for_write()
 
     std::string cookie = Board2chCompati::cookie_for_write();
 
+
+    // p2 ログイン中
+    if( CORE::get_loginp2()->login_now() ){
+        if( ! cookie.empty() ) cookie += "; ";
+        cookie += "cid=" + CORE::get_loginp2()->get_sessionid();
+    }
+
     // BE ログイン中
-    if( CORE::get_loginbe()->login_now() ){
+    else if( CORE::get_loginbe()->login_now() ){
         if( ! cookie.empty() ) cookie += "; ";
         cookie += "DMDM=" + CORE::get_loginbe()->get_username() + "; MDMD=" + CORE::get_loginbe()->get_passwd();
     }
@@ -141,6 +161,15 @@ const std::string Board2ch::cookie_for_write()
 }
 
 
+const std::string Board2ch::get_write_referer()
+{
+    // p2ログインの場合はとりあえず空文字
+    if( CORE::get_loginp2()->login_now() ) return std::string();
+
+    return Board2chCompati::get_write_referer();
+}
+
+
 // 新スレ作成時の書き込みメッセージ作成
 const std::string Board2ch::create_newarticle_message( const std::string& subject,
                                                        const std::string& name, const std::string& mail, const std::string& msg )
@@ -159,7 +188,7 @@ const std::string Board2ch::create_newarticle_message( const std::string& subjec
 
     // 2chログイン中
     // sidを送る
-    if( CORE::get_login2ch()->login_now() ){
+    if( ! CORE::get_loginp2()->login_now() && CORE::get_login2ch()->login_now() ){
         std::string sid = CORE::get_login2ch()->get_sessionid();
         ss_post << "&sid=" << MISC::url_encode( sid.c_str(), sid.length() );
     }
@@ -170,6 +199,18 @@ const std::string Board2ch::create_newarticle_message( const std::string& subjec
             << "&mail="    << MISC::charset_url_encode( mail, get_charset() )
             << "&MESSAGE=" << MISC::charset_url_encode( msg, get_charset() );
 
+    if( CORE::get_loginp2()->login_now() ){
+
+        ss_post << "&detect_hint=" << MISC::charset_url_encode( "◎◇", get_charset() )
+                << "&host=" << MISC::url_encode( MISC::get_hostname( get_root(), false ) )
+                << "&key="
+                << "&popup=1"
+                << "&rescount=1"
+                << "&ttitle_en="
+                << "&csrfid=" << MISC::url_encode( CORE::get_loginp2()->get_csrfid() )
+                << "&newthread=1";
+    }
+
 #ifdef _DEBUG
     std::cout << "Board2ch::create_newarticle_message " << ss_post.str() << std::endl;
 #endif
@@ -178,19 +219,46 @@ const std::string Board2ch::create_newarticle_message( const std::string& subjec
 }
 
 
+//
+// 新スレ作成時のbbscgi のURL
+//
+// (例) "http://www.hoge2ch.net/test/bbs.cgi"
+//
+//
+const std::string Board2ch::url_bbscgi_new()
+{
+    if( CORE::get_loginp2()->login_now() ) return CONFIG::get_url_loginp2() + "post.php";
+
+    return Board2chCompati::url_bbscgi_new();
+}
+
+
+//
+// 新スレ作成時のsubbbscgi のURL
+//
+// (例) "http://www.hoge2ch.net/test/subbbs.cgi"
+//
+const std::string Board2ch::url_subbbscgi_new()
+{
+    if( CORE::get_loginp2()->login_now() ) return CONFIG::get_url_loginp2() + "post.php";
+
+    return Board2chCompati::url_subbbscgi_new();
+}
+
+
 
 //
 // 新しくArticleBaseクラスを追加してそのポインタを返す
 //
 // cached : HDD にキャッシュがあるならtrue
 //
-ArticleBase* Board2ch::append_article( const std::string& id, bool cached )
+ArticleBase* Board2ch::append_article( const std::string& datbase, const std::string& id, const bool cached )
 {
     if( empty() ) return get_article_null();
 
-    ArticleBase* article = new DBTREE::Article2ch( url_datbase(), id, cached );
+    ArticleBase* article = new DBTREE::Article2ch( datbase, id, cached );
     if( article ){
-        get_list_article().push_back( article );
+        get_hash_article()->push( article );
 
         // 最大レス数セット
         article->set_number_max( get_number_max_res() );
