@@ -43,7 +43,7 @@ enum
 {
     SECTION_NUM = 5,
     LNG_RES = 16,
-    LNG_ID = 64,
+    LNG_ID = 256,
     LNG_LINK = 256,
     MAX_ANCINFO = 64,
     RANGE_REF = 20,
@@ -65,6 +65,14 @@ enum
 };
 
 
+#define IS_URL(node) \
+( node->type == NODE_LINK && node->linkinfo->link \
+&& ( std::string( node->linkinfo->link ).find( "http" ) == 0 \
+|| std::string( node->linkinfo->link ).find( "https" ) == 0  \
+|| std::string( node->linkinfo->link ).find( "ftp" ) == 0 )  \
+)
+
+
 using namespace DBTREE;
 
 
@@ -203,9 +211,9 @@ NODE* NodeTreeBase::res_header( int number )
 //
 // 指定したID の重複数( = 発言数 )
 //
-// 下のnum_id_name( int number )と違って検索するので遅い
+// 下の get_num_id_name( int number ) と違って検索するので遅い
 //
-int NodeTreeBase::get_num_id_name( const std::string& id )
+const int NodeTreeBase::get_num_id_name( const std::string& id )
 {
     if( id.empty() ) return 0;
 
@@ -233,7 +241,7 @@ int NodeTreeBase::get_num_id_name( const std::string& id )
 //
 // number番の ID の重複数
 //
-int NodeTreeBase::get_num_id_name( int number )
+const int NodeTreeBase::get_num_id_name( const int number )
 {
     NODE* head = res_header( number );
     if( ! head ) return 0;
@@ -345,13 +353,7 @@ std::list< int > NodeTreeBase::get_res_with_url()
 
                 while( node ){
 
-                    if( node->type == NODE_LINK
-                        && node->linkinfo->link
-                        && (
-                            std::string( node->linkinfo->link ).find( "http" ) == 0
-                            || std::string( node->linkinfo->link ).find( "https" ) == 0
-                            || std::string( node->linkinfo->link ).find( "ftp" ) == 0
-                            )
+                    if( IS_URL( node )
                         && ( ! m_abone_transparent || ! get_abone( i ) ) //  透明あぼーんしていない　or あぼーんしていない
                         ){
 
@@ -370,6 +372,33 @@ std::list< int > NodeTreeBase::get_res_with_url()
 }
 
 
+//
+// 含まれる URL をリストにして取得
+//
+std::list< std::string > NodeTreeBase::get_urls()
+{
+    std::list< std::string > list_urls;
+    for( int i = 1; i <= m_id_header; ++i ){
+
+        NODE* head = res_header( i );
+        if( head ){
+
+            for( int block = 0; block < BLOCK_NUM; ++block ){
+
+                NODE* node = head->headinfo->block[ block ];
+
+                while( node ){
+                    if( IS_URL( node ) ) list_urls.push_back( node->linkinfo->link );
+                    node = node->next_node;
+                }
+            }
+        }
+    }
+    
+    return list_urls;
+}
+
+
 
 //
 // res_num に含まれるレスを参照しているレス番号をリストにして取得
@@ -382,7 +411,7 @@ std::list< int > NodeTreeBase::get_res_reference( const std::list< int >& res_nu
 
     std::list< int >::const_iterator it_res = res_num.begin();
 
-    for( int i = ( *it_res ) + 1; i <= m_id_header; ++i ){
+    for( int i = 1; i <= m_id_header; ++i ){
 
         //  透明あぼーんは除外
         if( m_abone_transparent && get_abone( i ) ) continue;
@@ -416,8 +445,10 @@ std::list< int > NodeTreeBase::get_res_reference( const std::list< int >& res_nu
 
                                     const int number = ( *it_res );
 
-                                    // >>1-1000 みたいなアンカーは弾く
-                                    if( anc_to - anc_from < RANGE_REF && anc_from <= number && number <= anc_to
+                                    
+                                    if( i != number
+                                        && anc_to - anc_from < RANGE_REF // >>1-1000 みたいなアンカーは弾く
+                                        && anc_from <= number && number <= anc_to
                                         ) {
                                         list_resnum.push_back( i );
                                         goto EXIT_LOOP;
@@ -454,24 +485,40 @@ EXIT_LOOP:;
 //
 // mode_or == true なら OR抽出
 //
-std::list< int > NodeTreeBase::get_res_query( const std::string& query, bool mode_or )
+const std::list< int > NodeTreeBase::get_res_query( const std::string& query, const bool mode_or )
 {
     std::list< int > list_resnum;
     if( query.empty() ) return list_resnum;
 
-    JDLIB::Regex regex;
-    std::list< std::string > list_query = MISC::split_line( query );
+    std::list< JDLIB::Regex > list_regex;
+    const size_t offset = 0;
+    const bool icase = true; // 大文字小文字区別しない
+    const bool newline = true; // . に改行をマッチさせない
+    const bool usemigemo = true; // migemo使用
+    const bool wchar = true; // 全角半角の区別をしない
+
+    const std::list< std::string > list_query = MISC::split_line( query );
+    std::list< std::string >::const_iterator it_query;
+    for( it_query = list_query.begin(); it_query != list_query.end() ; ++it_query ){
+
+        const std::string &query = ( *it_query );
+        
+        list_regex.push_back( JDLIB::Regex() );
+        list_regex.back().compile( query, icase, newline, usemigemo, wchar );
+    }
 
     for( int i = 1; i <= m_id_header ; ++i ){
 
-        std::string res_str = get_res_str( i );
+        const std::string res_str = get_res_str( i );
 
         bool apnd = true;
         if( mode_or ) apnd = false;
-        std::list< std::string >::iterator it = list_query.begin();
-        for( ; it != list_query.end(); ++it ){
 
-            bool ret = regex.exec( ( *it ), res_str, 0, true );
+        std::list< JDLIB::Regex >::iterator it_regex;
+        for( it_regex = list_regex.begin(); it_regex != list_regex.end() ; ++it_regex ){
+
+            JDLIB::Regex &regex = ( *it_regex );
+            const bool ret = regex.exec( res_str, offset );
 
             // OR
             if( mode_or ){
@@ -659,8 +706,13 @@ const std::string NodeTreeBase::get_time_str( int number )
 
     std::string time_str;
     JDLIB::Regex regex;
+    const size_t offset = 0;
+    const bool icase = false;
+    const bool newline = true;
+    const bool usemigemo = false;
+    const bool wchar = false;
 
-    if( regex.exec( " 名前：.+]： +([0-9]*/[0-9]*/[0-9]*[^ ]* [0-9]*:[0-9]*[^ ]*).*$", res_str ) ){
+    if( regex.exec( " 名前：.+]： +([0-9]*/[0-9]*/[0-9]*[^ ]* [0-9]*:[0-9]*[^ ]*).*$", res_str, offset, icase, newline, usemigemo, wchar ) ){
         time_str = regex.str( 1 );
     }
 
@@ -779,6 +831,17 @@ NODE* NodeTreeBase::create_node_space( const int type )
 }
 
 
+//
+// 連続半角スペース
+//
+NODE* NodeTreeBase::create_node_multispace( const char* text, const int n )
+{
+    NODE* tmpnode = create_node_ntext( text, n, COLOR_CHAR, false );
+    tmpnode->type = NODE_MULTISP;
+    return tmpnode;
+}
+
+
 //
 // 水平タブノード
 //
@@ -1059,7 +1122,7 @@ void NodeTreeBase::download_dat( const bool check_update )
             std::cout << "open " << path_cache.c_str() << std::endl;
 #endif
 
-            m_fout = fopen( path_cache.c_str(), "ab" );
+            m_fout = fopen( to_locale_cstr( path_cache ), "ab" );
             if( m_fout == NULL ){
                 MISC::ERRMSG( "fopen failed : " + path_cache );
             }
@@ -1171,11 +1234,12 @@ void NodeTreeBase::receive_finish()
         && get_code() != HTTP_OK
         && get_code() != HTTP_PARTIAL_CONTENT
         && get_code() != HTTP_NOT_MODIFIED
+        && get_code() != HTTP_OLD
         ){
         std::ostringstream err;
         err << m_url << std::endl
             << "load failed. : " << get_str_code();
-        if( get_code() == HTTP_REDIRECT ) err << " location = " << location();
+        if( get_code() == HTTP_REDIRECT || get_code() == HTTP_REDIRECT ) err << " location = " << location();
         MISC::ERRMSG( err.str() );
     }
 
@@ -1191,7 +1255,7 @@ void NodeTreeBase::receive_finish()
         if( get_res_number() == 0 ){
 
             std::string path = CACHE::path_dat( m_url );
-            if( CACHE::file_exists( path ) == CACHE::EXIST_FILE ) unlink( path.c_str() );
+            if( CACHE::file_exists( path ) == CACHE::EXIST_FILE ) unlink( to_locale_cstr( path ) );
             set_date_modified( std::string() );
         }
 
@@ -1209,6 +1273,7 @@ void NodeTreeBase::receive_finish()
 
 #ifdef _DEBUG
     std::cout << "NodeTreeBase::receive_finish lng = " << m_lng_dat
+              << " raw lng = " << current_length()
               << " code = " << get_code() << " " << get_str_code()
               << " modified = " << get_date_modified() << std::endl;
 #endif    
@@ -1566,15 +1631,20 @@ void NodeTreeBase::parse_mail( NODE* header, const char* str, const int lng )
     else header->headinfo->sage = TRUE;
 
     header->headinfo->block[ BLOCK_MAIL ] = create_node_block();
-    create_node_text( "[", color );
 
-    const bool digitlink = true;
-    const bool bold = false;
-    const bool ahref = false;
-    const bool sssp = false;
-    parse_html( str, lng, color, digitlink, bold, ahref, sssp );
+    if( ! lng )  create_node_text( "[]", color );
 
-    create_node_text( "]", color );
+    else{
+        create_node_text( "[", color );
+
+        const bool digitlink = true;
+        const bool bold = false;
+        const bool ahref = false;
+        const bool sssp = false;
+        parse_html( str, lng, color, digitlink, bold, ahref, sssp );
+
+        create_node_text( "]", color );
+    }
 }
 
 
@@ -1585,6 +1655,7 @@ void NodeTreeBase::parse_date_id( NODE* header, const char* str, const int lng )
 {
     int start = 0;
     int lng_text = 0;
+    int lng_link_tmp;
     char tmplink[ LNG_LINK ];
 
     int lng_id_tmp;
@@ -1603,8 +1674,20 @@ void NodeTreeBase::parse_date_id( NODE* header, const char* str, const int lng )
         while( start_block + lng_block < lng && str[ start_block + lng_block ] != ' ' ) ++lng_block;
         if( !lng_block ) break;
 
-        // ID ( ??? の時は除く )
-        if( str[ start_block ] == 'I' && str[ start_block + 1 ] == 'D' && str[ start_block + 3 ] != '?' ){
+        if(
+            // ID ( ??? の時は除く )
+            ( str[ start_block ] == 'I' && str[ start_block + 1 ] == 'D' && str[ start_block + 3 ] != '?' )
+
+            // HOST
+            || ( str[ start_block + 0 ] == 'H' && str[ start_block + 1 ] == 'O' && str[ start_block + 2 ] == 'S' && str[ start_block + 3 ] == 'T' )
+
+            // 発言元
+            || (    str[ start_block + 0 ] == (char)0xe7 && str[ start_block + 1 ] == (char)0x99 && str[ start_block + 2 ] == (char)0xba // 発
+                 && str[ start_block + 3 ] == (char)0xe4 && str[ start_block + 4 ] == (char)0xbf && str[ start_block + 5 ] == (char)0xa1 // 言
+                 && str[ start_block + 6 ] == (char)0xe5 && str[ start_block + 7 ] == (char)0x85 && str[ start_block + 8 ] == (char)0x83 // 元
+                )
+
+            ){
 
             // フラッシュ
             if( lng_text ){
@@ -1612,19 +1695,36 @@ void NodeTreeBase::parse_date_id( NODE* header, const char* str, const int lng )
                 create_node_ntext( str + start, lng_text, COLOR_CHAR );
             }
 
+            int offset = 0;
+            if( str[ start_block ] == 'I' ) offset = 3;
+            else if( str[ start_block ] == 'H' ){
+                offset = 5;
+
+                // HOST: の場合は途中で空白が入るときがあるので最後までブロックを伸ばす
+                lng_block = lng - start_block;
+            }
+            else if( str[ start_block ] == (char)0xe7 ) offset = 10;
+
             // id 取得
-            lng_id_tmp = lng_block -3;
-            memcpy( tmpid, str + start_block + 3, lng_id_tmp );
+            lng_id_tmp = MIN( lng_block, LNG_ID - 16 );
+            memcpy( tmpid, str + start_block, lng_id_tmp );
             tmpid[ lng_id_tmp ] = '\0';
             
             // リンク文字作成
             memcpy( tmplink, PROTO_ID, sizeof( PROTO_ID ) );
             memcpy( tmplink + sizeof( PROTO_ID ) - 1, tmpid, lng_id_tmp + 1 );
-            
+            lng_link_tmp = strlen( tmplink );
+
+            // 後ろに●が付いていたら取り除く
+            if( tmplink[ lng_link_tmp - 3 ] == (char)0xe2 && tmplink[ lng_link_tmp - 2 ] == (char)0x97 && tmplink[ lng_link_tmp - 1 ] == (char)0x8f ){
+                lng_link_tmp -= 3;
+                tmplink[ lng_link_tmp ] = '\0';
+            }
+
             // リンク作成
             header->headinfo->block[ BLOCK_ID_NAME ] = create_node_block();
-            create_node_link( "ID:", 3 , tmplink, strlen( tmplink ), COLOR_CHAR, false );
-            create_node_ntext( tmpid, lng_id_tmp, COLOR_CHAR);
+            create_node_link( tmpid, offset, tmplink, lng_link_tmp, COLOR_CHAR, false );
+            create_node_ntext( tmpid +offset, lng_id_tmp -offset, COLOR_CHAR);
 
             // 発言回数ノード作成
             create_node_idnum();
@@ -1723,8 +1823,17 @@ void NodeTreeBase::parse_html( const char* str, const int lng, const int color_t
     const char* pos_end = str + lng;
     int lng_text = 0;
     
-    // 行頭の空白は全て除く
-    while( *pos == ' ' ) ++pos;
+    if( *pos == ' ' ){
+
+        pos++;  // 一文字だけなら取り除く
+
+        // 連続半角空白
+        if( *pos == ' ' ){
+
+            while( *pos == ' ' ) m_parsed_text[ lng_text++ ] = *(pos++);
+            create_node_multispace( m_parsed_text, lng_text ); lng_text = 0;
+        }
+    }
    
     for( ; pos < pos_end; ++pos, digitlink = false ){
 
@@ -1839,7 +1948,7 @@ void NodeTreeBase::parse_html( const char* str, const int lng, const int color_t
 
                 int n_in = 0;
                 int n_out = 0;
-                DBTREE::decode_char( "&#12539;", n_in, m_parsed_text + lng_text, n_out );
+                DBTREE::decode_char( "&#12539;", n_in, m_parsed_text + lng_text, n_out, false );
                 lng_text += n_out;
             }
 
@@ -1876,9 +1985,19 @@ void NodeTreeBase::parse_html( const char* str, const int lng, const int color_t
                 // 改行ノード作成
                 create_node_br();
 
-                // 改行直後と行頭の空白は全て除く
                 while( *pos != '>' ) ++pos; ++pos;
-                while( *pos == ' ' ) ++pos;
+
+                if( *pos == ' ' ){
+
+                    pos++;  // 一文字だけなら取り除く
+
+                    // 連続半角空白
+                    if( *pos == ' ' ){
+
+                        while( *pos == ' ' ) m_parsed_text[ lng_text++ ] = *(pos++);
+                        create_node_multispace( m_parsed_text, lng_text ); lng_text = 0;
+                    }
+                }
             }
 
             // forのところで++されるので--しておく
@@ -1972,7 +2091,7 @@ void NodeTreeBase::parse_html( const char* str, const int lng, const int color_t
         // 特殊文字デコード
         if( *pos == '&' ){
 
-            int ret_decode = DBTREE::decode_char( pos, n_in, m_parsed_text + lng_text, n_out );
+            const int ret_decode = DBTREE::decode_char( pos, n_in, m_parsed_text + lng_text, n_out, false );
 
             if( ret_decode != NODE_NONE ){
 
@@ -2010,8 +2129,22 @@ void NodeTreeBase::parse_html( const char* str, const int lng, const int color_t
             continue;
         }
 
-        // 連続する空白は一個にする
-        while( *pos == ' ' && *( pos + 1 ) == ' ' ) ++pos;
+        ///////////////////////
+        // 連続半角空白
+        if( *pos == ' ' && *( pos + 1 ) == ' ' ){
+
+            m_parsed_text[ lng_text++ ] = *(pos++);
+
+            // フラッシュしてから連続半角ノードを作る
+            create_node_ntext( m_parsed_text, lng_text, color_text, bold ); lng_text = 0;
+
+            while( *pos == ' ' ) m_parsed_text[ lng_text++ ] = *(pos++);
+            create_node_multispace( m_parsed_text, lng_text ); lng_text = 0;
+
+            // forのところで++されるので--しておく
+            --pos;
+            continue;
+        }
 
         m_parsed_text[ lng_text++ ] = *pos;
     }
@@ -2039,6 +2172,9 @@ void NodeTreeBase::parse_write( const char* str, const int lng, const int max_ln
     const char* pos = str;
     const char* pos_end = str + lng;
 
+    int offset_num;
+    int lng_num;
+
     char* pos_write = m_buffer_write;
 
     // 行頭の空白は全て除く
@@ -2110,6 +2246,17 @@ void NodeTreeBase::parse_write( const char* str, const int lng, const int max_ln
             continue;
         }
 
+        // 数字参照
+        else if( *pos == '&' && *( pos + 1 ) == '#' && ( lng_num = MISC::spchar_number_ln( pos, offset_num ) ) != -1 ){
+
+            const int num = MISC::decode_spchar_number( pos, offset_num, lng_num );
+            const int n_out = MISC::ucs2toutf8( num, pos_write );
+            pos_write += n_out;
+            pos += offset_num + lng_num;
+
+            continue;
+        }
+
         head = false;
         *(pos_write++) = *pos;
     }
@@ -2134,8 +2281,8 @@ void NodeTreeBase::parse_write( const char* str, const int lng, const int max_ln
 //
 // 戻り値 : アンカーが現れれば true
 //
-bool NodeTreeBase::check_anchor( int mode, const char* str_in,
-                                 int& n_in, char* str_out, char* str_link, int lng_link, ANCINFO* ancinfo )
+const bool NodeTreeBase::check_anchor( const int mode, const char* str_in,
+                                       int& n_in, char* str_out, char* str_link, int lng_link, ANCINFO* ancinfo )
 {
     char tmp_out[ 64 ];
     int lng_out = 0;
@@ -2197,9 +2344,9 @@ bool NodeTreeBase::check_anchor( int mode, const char* str_in,
     }
 
     // 数字かチェック
-    unsigned int n, dig;
-    ancinfo->anc_from = ancinfo->anc_to = MISC::str_to_uint( pos, dig, n );
-    if( dig == 0 || dig > MAX_LINK_DIGIT || ancinfo->anc_from == 0 ){
+    size_t n, dig;
+    int num = MISC::str_to_uint( pos, dig, n );
+    if( dig == 0 || dig > MAX_LINK_DIGIT || num == 0 ){
 
         // モード2で数字が長すぎるときは飛ばす
         if( mode == 2 && dig > MAX_LINK_DIGIT ) n_in = ( int )( pos - str_in ) + n; 
@@ -2213,16 +2360,34 @@ bool NodeTreeBase::check_anchor( int mode, const char* str_in,
     memcpy( str_out, tmp_out, lng_out );
     memcpy( str_out + lng_out, pos, n );
     str_out[ lng_out + n ] = '\0';
-
-    // アンカー文字
-    snprintf( str_link, lng_link, "%d", ancinfo->anc_from );
     pos += n;
     lng_out += n;    
 
+    // </a>をキャンセル
+    if( *( pos ) == '<' && *( pos + 1 ) == '/' && ( *( pos + 2 ) == 'a' || *( pos + 2 ) == 'A' ) && *( pos + 3 ) == '>' ){
 
-    // dat形式では "&gt;&gt;数字"のパターンの場合には後に</a>がついてるのでのぞく
-    if( *( pos ) == '<' && *( pos + 1 ) == '/' && ( *( pos + 2 ) == 'a' || *( pos + 2 ) == 'A' ) && *( pos + 3 ) == '>' ) pos += 4;
+        pos += 4;
 
+        // もう一度数字チェック
+        // >>1１ を書き込むと <a href="..">&gt;&gt;1</a>１ となるため
+        size_t n2, dig2;
+        const int num2 = MISC::str_to_uint( pos, dig2, n2 );
+        if( dig2 > 0 && dig2 <= MAX_LINK_DIGIT ){
+
+            for( size_t i = 0; i < dig2; ++i ) num *= 10;
+            num += num2;
+
+            memcpy( str_out + lng_out, pos, n2 );
+            str_out[ lng_out + n2 ] = '\0';
+            pos += n2;
+            lng_out += n2;
+        }
+    }
+
+    ancinfo->anc_from = ancinfo->anc_to = num;
+
+    // アンカー文字
+    snprintf( str_link, lng_link, "%d", ancinfo->anc_from );
 
     // "-" でつながってる場合同じことをもう一回
     int offset = 0;
@@ -2292,44 +2457,24 @@ const int NodeTreeBase::check_link( const char* str_in, const int lng_in, int& n
     // リンクの長さを取得
     n_in = delim_pos;
     bool url_encode = false;
+    int n_in_tmp, n_out_tmp;
     char cchar = *( str_in + n_in );
+
     while(
+
         // バッファサイズを超えない
         n_in < lng_in
+
         // URLとして扱う文字かどうか
         && MISC::is_url_char( &cchar, loose_url )
+
         // HTML特殊文字は除く( &〜; )
         && ! (
             *( str_in + n_in ) == '&'
-            && (
-                 (
-                   // quot;
-                   *( str_in + n_in + 1 ) == 'q'
-                   && *( str_in + n_in + 2 ) == 'u'
-                   && *( str_in + n_in + 3 ) == 'o'
-                   && *( str_in + n_in + 4 ) == 't'
-                   && *( str_in + n_in + 5 ) == ';'
-                 ) || (
-                   // nbsp;
-                   *( str_in + n_in + 1 ) == 'n'
-                   && *( str_in + n_in + 2 ) == 'b'
-                   && *( str_in + n_in + 3 ) == 's'
-                   && *( str_in + n_in + 4 ) == 'p'
-                   && *( str_in + n_in + 5 ) == ';'
-                 ) || (
-                   // lt;
-                   *( str_in + n_in + 1 ) == 'l'
-                   && *( str_in + n_in + 2 ) == 't'
-                   && *( str_in + n_in + 3 ) == ';'
-                 ) || (
-                   // gt;
-                   *( str_in + n_in + 1 ) == 'g'
-                   && *( str_in + n_in + 2 ) == 't'
-                   && *( str_in + n_in + 3 ) == ';'
-                 )
+            && DBTREE::decode_char( str_in + n_in, n_in_tmp, NULL, n_out_tmp, true ) != DBTREE::NODE_NONE
             )
-        )
-    ){
+        ){
+
         // "^"と"|"はエンコードする
         // "[]"はダウンローダに渡す用途のためにエンコードしないでおく
         if( loose_url && ( cchar == '^' || cchar == '|' ) ) url_encode = true;
@@ -2677,6 +2822,11 @@ const bool NodeTreeBase::check_abone_word( const int number )
 
     const std::string res_str = get_res_str( number );
     JDLIB::Regex regex;
+    const size_t offset = 0;
+    const bool icase = false;
+    const bool newline = true;
+    const bool usemigemo = false;
+    const bool wchar = false;
 
     // ローカル NG word
     if( check_word ){
@@ -2695,7 +2845,7 @@ const bool NodeTreeBase::check_abone_word( const int number )
 
         std::list< std::string >::iterator it = m_list_abone_regex.begin();
         for( ; it != m_list_abone_regex.end(); ++it ){
-            if( regex.exec( *it, res_str ) ){
+            if( regex.exec( *it, res_str, offset, icase, newline, usemigemo, wchar ) ){
                 head->headinfo->abone = true;
                 return true;
             }
@@ -2719,7 +2869,7 @@ const bool NodeTreeBase::check_abone_word( const int number )
 
         std::list< std::string >::iterator it = m_list_abone_regex_board.begin();
         for( ; it != m_list_abone_regex_board.end(); ++it ){
-            if( regex.exec( *it, res_str ) ){
+            if( regex.exec( *it, res_str, offset, icase, newline, usemigemo, wchar ) ){
                 head->headinfo->abone = true;
                 return true;
             }
@@ -2743,7 +2893,7 @@ const bool NodeTreeBase::check_abone_word( const int number )
 
         std::list< std::string >::iterator it = m_list_abone_regex_global.begin();
         for( ; it != m_list_abone_regex_global.end(); ++it ){
-            if( regex.exec( *it, res_str ) ){
+            if( regex.exec( *it, res_str, offset, icase, newline, usemigemo, wchar ) ){
                 head->headinfo->abone = true;
                 return true;
             }
@@ -2843,7 +2993,7 @@ void NodeTreeBase::update_reference( int from_number, int to_number )
 //
 // number番のレスが参照しているレスのレス番号の参照数(num_reference)と色をチェック
 //
-void NodeTreeBase::check_reference( int number )
+void NodeTreeBase::check_reference( const int number )
 {
     NODE* head = res_header( number );
     if( ! head ) return;
@@ -2852,11 +3002,49 @@ void NodeTreeBase::check_reference( int number )
     if( head->headinfo->abone ) return;
 
     // 2重チェック防止用
-    bool checked[ number ];
-    memset( checked, 0, sizeof( bool ) * number );
+    bool checked[ MAX_RESNUMBER ];
+    memset( checked, 0, sizeof( bool ) * MAX_RESNUMBER );
 
     const bool posted = m_vec_posted.size();
 
+    // 過去のレスから number 番へのアンカーがあった場合
+    if( m_map_future_refer.size() ){
+
+        std::map< int, std::vector< int > >::iterator it_map = m_map_future_refer.find( number );
+        if( it_map != m_map_future_refer.end() ){
+
+            const int size = ( (*it_map).second ).size();
+
+            inc_reference( head, size );
+
+#ifdef _DEBUG
+            std::cout << "found number = " << number << " size = " << size << std::endl;
+#endif
+            // 過去のレスへ自分の書き込みへの参照マークを付ける
+            if( posted && m_vec_posted[ number ] ){
+
+                for( int i = 0; i < size; ++ i ){
+
+                    const int from = ( (*it_map).second )[ i ];
+#ifdef _DEBUG
+                    std::cout << "from " << from << std::endl;
+#endif
+                    NODE* tmphead = res_header( from );
+                    if( tmphead && ! tmphead->headinfo->abone ){
+                        if( ! m_vec_refer_posted.size() ) m_vec_refer_posted.resize( MAX_RESNUMBER );
+                        m_vec_refer_posted[ from ] = true;
+                    }
+                }
+            }
+
+            m_map_future_refer.erase( it_map );
+#ifdef _DEBUG
+            std::cout << "map_future_refer size = " << m_map_future_refer.size() << std::endl;
+#endif
+        }
+    }
+
+
     for( int block = 0; block < BLOCK_NUM; ++block ){
 
         NODE* node = head->headinfo->block[ block ];
@@ -2878,9 +3066,7 @@ void NodeTreeBase::check_reference( int number )
                         if( anc_from == 0 ) break;
                         ++anc;
 
-                        // number-1 番以下のレスだけを見る
-                        if( anc_from >= number ) continue;
-                        anc_to = MIN( anc_to, number -1 );
+                        anc_to = MIN( anc_to, MAX_RESNUMBER );
 
                         // >>1-1000 みたいなアンカーは弾く
                         if( anc_to - anc_from >= RANGE_REF ) continue;
@@ -2890,6 +3076,37 @@ void NodeTreeBase::check_reference( int number )
                             // 既にチェックしている
                             if( checked[ i ] ) continue;
 
+                            // 自分自身
+                            if( i == number ) continue;
+
+                            // 未来へのレス
+                            if( i > number ){
+#ifdef _DEBUG
+                                std::cout << "future ref " << i << " from " << number << std::endl;
+#endif
+                                std::map< int, std::vector< int > >::iterator it_map = m_map_future_refer.find( i );
+                                if( it_map != m_map_future_refer.end() ){
+
+                                    ( (*it_map).second ).push_back( number );
+#ifdef _DEBUG
+                                    std::cout << "found size = " << ( (*it_map).second ).size() << std::endl;
+#endif
+                                }
+                                else{
+#ifdef _DEBUG
+                                    std::cout << "not found\n";
+#endif
+                                    std::pair< int, std::vector< int > > tmp_pair;
+                                    tmp_pair.first = i;
+                                    tmp_pair.second.push_back( number );
+                                    m_map_future_refer.insert( tmp_pair );
+                                }
+
+                                continue;
+                            }
+
+
+                            // 過去へのレス
                             NODE* tmphead = res_header( i );
                             if( tmphead
                                 && ! tmphead->headinfo->abone // 対象スレがあぼーんしていたらカウントしない
@@ -2904,23 +3121,11 @@ void NodeTreeBase::check_reference( int number )
                                     m_vec_refer_posted[ number ] = true;
 
 #ifdef _DEBUG
-                                    std::cout << "ref " << i << " " << number << std::endl;
+                                    std::cout << "ref " << i << " from " << number << std::endl;
 #endif
                                 }
 
-                                // 参照数を更新して色を変更
-                                ++( tmphead->headinfo->num_reference );
-
-                                // 参照回数大
-                                if( tmphead->headinfo->num_reference >= m_num_reference[ LINK_HIGH ] )
-                                    tmphead->headinfo->block[ BLOCK_NUMBER ]->next_node->color_text = COLOR_CHAR_LINK_HIGH;
-
-                                // 参照回数中
-                                else if( tmphead->headinfo->num_reference >= m_num_reference[ LINK_LOW ] )
-                                    tmphead->headinfo->block[ BLOCK_NUMBER ]->next_node->color_text = COLOR_CHAR_LINK_LOW;
-
-                                // 参照無し
-                                else tmphead->headinfo->block[ BLOCK_NUMBER ]->next_node->color_text = COLOR_CHAR_LINK;
+                                inc_reference( tmphead, 1 );
                             }
                         }
                     }
@@ -2936,6 +3141,26 @@ void NodeTreeBase::check_reference( int number )
 }
 
 
+//
+// 参照数を count だけ増やしてして色を変更
+//
+void NodeTreeBase::inc_reference( NODE* head, const int count )
+{
+    head->headinfo->num_reference += count;
+
+    // 参照回数大
+    if( head->headinfo->num_reference >= m_num_reference[ LINK_HIGH ] )
+        head->headinfo->block[ BLOCK_NUMBER ]->next_node->color_text = COLOR_CHAR_LINK_HIGH;
+
+    // 参照回数中
+    else if( head->headinfo->num_reference >= m_num_reference[ LINK_LOW ] )
+        head->headinfo->block[ BLOCK_NUMBER ]->next_node->color_text = COLOR_CHAR_LINK_LOW;
+
+    // 参照無し
+    else head->headinfo->block[ BLOCK_NUMBER ]->next_node->color_text = COLOR_CHAR_LINK;
+}
+
+
 // 発言数(( num_id_name ))とIDの色のクリア
 void NodeTreeBase::clear_id_name()
 {
@@ -2953,7 +3178,7 @@ void NodeTreeBase::clear_id_name()
 //
 // from_number番から to_number 番までの発言数の更新
 //
-void NodeTreeBase::update_id_name( int from_number, int to_number )
+void NodeTreeBase::update_id_name( const int from_number, const int to_number )
 {
     if( ! CONFIG::get_check_id() ) return;
 
@@ -2967,53 +3192,66 @@ void NodeTreeBase::update_id_name( int from_number, int to_number )
 //
 // number番のレスの発言数を更新
 //
-void NodeTreeBase::check_id_name( int number )
+void NodeTreeBase::check_id_name( const int number )
 {
     NODE* header = res_header( number );
+    if( ! header ) return;
+//    if( header->headinfo->abone ) return;
+    if( ! header->headinfo->block[ BLOCK_ID_NAME ] ) return;
 
-    // あぼーんしているならチェックしない
-    if( header->headinfo->abone ) return;
+    const char* str_id = header->headinfo->block[ BLOCK_ID_NAME ]->next_node->linkinfo->link;
 
-    if( header && header->headinfo->block[ BLOCK_ID_NAME ] ){
+    // 同じIDのレスを持つ一つ前のレスを探す
+    NODE* tmphead;
+    NODE* prehead = NULL;
+    for( int i = header->id_header -1 ; i >= 1 ; --i ){
 
-        char* str_id = header->headinfo->block[ BLOCK_ID_NAME ]->next_node->linkinfo->link;
+        tmphead = m_vec_header[ i ];
 
-        // 以前に出た同じIDのレスの発言数を更新しつつ発言回数を調べる
-        int num_id_name = 1;
-        for( int i = 1 ; i < header->id_header; ++i ){
-
-            NODE* tmphead = m_vec_header[ i ];
-
-            if( tmphead
-                && ! tmphead->headinfo->abone // 対象スレがあぼーんしていたらカウントしない
-                && tmphead->headinfo->block[ BLOCK_ID_NAME ]
-                && strcmp( str_id, tmphead->headinfo->block[ BLOCK_ID_NAME ]->next_node->linkinfo->link ) == 0 ){
-
-                set_num_id_name( tmphead, tmphead->headinfo->num_id_name+1 );
-                ++num_id_name;
-            }
+        if( tmphead
+//            && ! tmphead->headinfo->abone // 対象スレがあぼーんしていたらカウントしない
+            && tmphead->headinfo->block[ BLOCK_ID_NAME ]
+            && str_id[ 0 ] == tmphead->headinfo->block[ BLOCK_ID_NAME ]->next_node->linkinfo->link[ 0 ]
+            && strcmp( str_id, tmphead->headinfo->block[ BLOCK_ID_NAME ]->next_node->linkinfo->link ) == 0 ){
+            prehead = tmphead;
+            break;
         }
+    }
 
-        set_num_id_name( header, num_id_name );
+    // 見つからなかった
+    if( ! prehead ) set_num_id_name( header, 1, NULL );
+
+    // 見つかった
+    else{
+
+        set_num_id_name( header, prehead->headinfo->num_id_name+1, prehead );
+
+        // 以前に出た同じIDのレスの発言数を更新
+        tmphead = prehead;
+        while( tmphead ){
+
+            set_num_id_name( tmphead, tmphead->headinfo->num_id_name+1, tmphead->headinfo->pre_id_name_header );
+            tmphead = tmphead->headinfo->pre_id_name_header;
+        }
     }
 }
 
 
-
 //
 // 発言数( num_id_name )の更新
 //
 // IDノードの色も変更する
 //
-void NodeTreeBase::set_num_id_name( NODE* header, int num_id_name )
+void NodeTreeBase::set_num_id_name( NODE* header, const int num_id_name, NODE* pre_id_name_header )
 {
-    if( header->headinfo->block[ BLOCK_ID_NAME ] ){
+    if( ! header->headinfo->block[ BLOCK_ID_NAME ] ) return;
 
-        header->headinfo->num_id_name = num_id_name;        
-        if( num_id_name >= m_num_id[ LINK_HIGH ] ) header->headinfo->block[ BLOCK_ID_NAME ]->next_node->color_text = COLOR_CHAR_LINK_HIGH;
-        else if( num_id_name >= m_num_id[ LINK_LOW ] ) header->headinfo->block[ BLOCK_ID_NAME ]->next_node->color_text = COLOR_CHAR_LINK;
-        else header->headinfo->block[ BLOCK_ID_NAME ]->next_node->color_text = COLOR_CHAR;
-    }
+    header->headinfo->num_id_name = num_id_name;        
+    header->headinfo->pre_id_name_header = pre_id_name_header;
+
+    if( num_id_name >= m_num_id[ LINK_HIGH ] ) header->headinfo->block[ BLOCK_ID_NAME ]->next_node->color_text = COLOR_CHAR_LINK_HIGH;
+    else if( num_id_name >= m_num_id[ LINK_LOW ] ) header->headinfo->block[ BLOCK_ID_NAME ]->next_node->color_text = COLOR_CHAR_LINK;
+    else header->headinfo->block[ BLOCK_ID_NAME ]->next_node->color_text = COLOR_CHAR;
 }
 
 
