@@ -46,10 +46,12 @@ enum{
 #define ITEM_NAME_SINCE "since"
 #define ITEM_NAME_LASTWRITE "最終書込"
 #define ITEM_NAME_SPEED "速度"
+#define ITEM_NAME_DIFF "増分"
 
 #define ITEM_NAME_WRITEMSG  "書き込み"
 #define ITEM_NAME_OPENBOARD "板を開く"
 #define ITEM_NAME_OPENARTICLETAB   "タブでスレを開く"
+#define ITEM_NAME_REGETARTICLE "スレ情報を消さずに再取得"
 #define ITEM_NAME_BOOKMARK   "しおりを設定/解除"
 #define ITEM_NAME_SEARCH    "検索"
 #define ITEM_NAME_DRAWOUT    "抽出"
@@ -57,8 +59,8 @@ enum{
 #define ITEM_NAME_STOPLOADING "読み込み中止"
 #define ITEM_NAME_FAVORITE  "お気に入りに追加"
 #define ITEM_NAME_FAVORITE_ARTICLE  "スレをお気に入りに追加"
-#define ITEM_NAME_CHECK_UPDATE_ROOT "更新チェック"
-#define ITEM_NAME_CHECK_UPDATE_OPEN_ROOT "更新チェックしてタブで開く"
+#define ITEM_NAME_CHECK_UPDATE_ROOT "サイドバー更新チェック"
+#define ITEM_NAME_CHECK_UPDATE_OPEN_ROOT "サイドバー更新チェックして開く"
 
 #define ITEM_NAME_COPY      "コピー"
 #define ITEM_NAME_COPY_URL      "URLをコピー"
@@ -91,6 +93,7 @@ enum{
 #define ITEM_NAME_ABONE_ARTICLE   "スレをあぼ〜んする"
 #define ITEM_NAME_QUOTE_SELECTION   "引用してレスする"
 #define ITEM_NAME_OPEN_BROWSER      "ブラウザで開く"
+#define ITEM_NAME_OPEN_CACHE_BROWSER      "キャッシュをブラウザで開く"
 #define ITEM_NAME_USER_COMMAND      "ユーザコマンド"
 #define ITEM_NAME_ETC         "その他"
 #define ITEM_NAME_SAVE_DAT    "datを保存"
@@ -128,10 +131,12 @@ enum
     ITEM_SINCE,
     ITEM_LASTWRITE,
     ITEM_SPEED,
+    ITEM_DIFF,
 
     ITEM_WRITEMSG,
     ITEM_OPENBOARD,
     ITEM_OPENARTICLETAB,
+    ITEM_REGETARTICLE,
     ITEM_BOOKMARK,
     ITEM_SEARCH,
     ITEM_DRAWOUT,
@@ -173,6 +178,7 @@ enum
     ITEM_ABONE_ARTICLE,
     ITEM_QUOTE_SELECTION,
     ITEM_OPEN_BROWSER,
+    ITEM_OPEN_CACHE_BROWSER,
     ITEM_USER_COMMAND,
     ITEM_ETC,
     ITEM_SAVE_DAT,
@@ -238,6 +244,7 @@ enum
 #define PROTO_BE "BE://"
 #define PROTO_ABONE "abone://"
 #define PROTO_OR "or://"
+#define PROTO_BM "bm://"
 #define PROTO_BROKEN "bloken://"
 #define PROTO_POSTLOG "postlog://"
 #define PROTO_SSSP "sssp://"
@@ -271,4 +278,7 @@ enum
 
 #define URL_BOARD_LOCAL "file:///local"
 
+#define URL_SEARCH_ALLBOARD "allboard"
+#define URL_SEARCH_TITLE "title"
+
 #endif
