@@ -12,11 +12,13 @@
 
 #include "bkmark_update.h"
 #include "bkmark.h"
+#include "bkmark_broken_subject.h"
 #include "bkmark_thread.h"
 
 #include "update.h"
 #include "newthread.h"
 #include "newthread_hour.h"
+#include "broken_subject.h"
 #include "check.h"
 #include "down.h"
 #include "write.h"
@@ -27,6 +29,10 @@
 
 #include "dir.h"
 #include "favorite.h"
+#include "hist.h"
+#include "hist_board.h"
+#include "hist_close.h"
+
 #include "board.h"
 #include "board_update.h"
 #include "board_updated.h"
@@ -36,6 +42,11 @@
 #include "thread_old.h"
 #include "image.h"
 #include "link.h"
+#include "info.h"
+
+#if GTKMMVER <= 240
+#include "play.h"
+#endif
 
 
 ICON::ICON_Manager* instance_icon_manager = NULL;
@@ -79,11 +90,13 @@ ICON_Manager::ICON_Manager()
 
     m_list_icons[ ICON::BKMARK_UPDATE ] = Gdk::Pixbuf::create_from_inline( sizeof( icon_bkmark_update ), icon_bkmark_update );
     m_list_icons[ ICON::BKMARK ] = Gdk::Pixbuf::create_from_inline( sizeof( icon_bkmark ), icon_bkmark );
+    m_list_icons[ ICON::BKMARK_BROKEN_SUBJECT ] = Gdk::Pixbuf::create_from_inline( sizeof( icon_bkmark_broken_subject ), icon_bkmark_broken_subject );
     m_list_icons[ ICON::BKMARK_THREAD ] = Gdk::Pixbuf::create_from_inline( sizeof( icon_bkmark_thread ), icon_bkmark_thread );
 
     m_list_icons[ ICON::UPDATE ] = Gdk::Pixbuf::create_from_inline( sizeof( icon_update ), icon_update );
     m_list_icons[ ICON::NEWTHREAD ] = Gdk::Pixbuf::create_from_inline( sizeof( icon_newthread ), icon_newthread );
     m_list_icons[ ICON::NEWTHREAD_HOUR ] = Gdk::Pixbuf::create_from_inline( sizeof( icon_newthread_hour ), icon_newthread_hour );
+    m_list_icons[ ICON::BROKEN_SUBJECT ] = Gdk::Pixbuf::create_from_inline( sizeof( icon_broken_subject ), icon_broken_subject );
     m_list_icons[ ICON::CHECK ] = Gdk::Pixbuf::create_from_inline( sizeof( icon_check ), icon_check );
     m_list_icons[ ICON::DOWN ] = Gdk::Pixbuf::create_from_inline( sizeof( icon_down ), icon_down );
     m_list_icons[ ICON::WRITE ] = Gdk::Pixbuf::create_from_inline( sizeof( icon_write ), icon_write );
@@ -94,6 +107,10 @@ ICON_Manager::ICON_Manager()
 
     m_list_icons[ ICON::DIR ] = Gdk::Pixbuf::create_from_inline( sizeof( icon_dir ), icon_dir );
     m_list_icons[ ICON::FAVORITE ] = Gdk::Pixbuf::create_from_inline( sizeof( icon_favorite ), icon_favorite );
+    m_list_icons[ ICON::HIST ] = Gdk::Pixbuf::create_from_inline( sizeof( icon_hist ), icon_hist );
+    m_list_icons[ ICON::HIST_BOARD ] = Gdk::Pixbuf::create_from_inline( sizeof( icon_hist_board ), icon_hist_board );
+    m_list_icons[ ICON::HIST_CLOSE ] = Gdk::Pixbuf::create_from_inline( sizeof( icon_hist_close ), icon_hist_close );
+
     m_list_icons[ ICON::BOARD ] = Gdk::Pixbuf::create_from_inline( sizeof( icon_board ), icon_board );
     m_list_icons[ ICON::BOARD_UPDATE ] = Gdk::Pixbuf::create_from_inline( sizeof( icon_board_update ), icon_board_update );
     m_list_icons[ ICON::BOARD_UPDATED ] = Gdk::Pixbuf::create_from_inline( sizeof( icon_board_updated ), icon_board_updated );
@@ -103,6 +120,11 @@ ICON_Manager::ICON_Manager()
     m_list_icons[ ICON::THREAD_OLD ] = Gdk::Pixbuf::create_from_inline( sizeof( icon_thread_old ), icon_thread_old );
     m_list_icons[ ICON::IMAGE ] = Gdk::Pixbuf::create_from_inline( sizeof( icon_image ), icon_image );
     m_list_icons[ ICON::LINK ] = Gdk::Pixbuf::create_from_inline( sizeof( icon_link ), icon_link );
+    m_list_icons[ ICON::INFO ] = Gdk::Pixbuf::create_from_inline( sizeof( icon_info ), icon_info );
+
+#if GTKMMVER <= 240
+    m_list_icons[ ICON::PLAY ] = Gdk::Pixbuf::create_from_inline( sizeof( icon_play ), icon_play );
+#endif
 
     m_list_icons[ ICON::TRANSPARENT ] = Gdk::Pixbuf::create( Gdk::COLORSPACE_RGB, true, 8, 1, 1 );
     m_list_icons[ ICON::TRANSPARENT ]->fill( 0 );
