@@ -7,6 +7,13 @@
 #ifndef _ICONNAGER_H
 #define _ICONNAGER_H
 
+#ifdef _WIN32
+ #ifdef TRANSPARENT
+ // will be conflict to wingdi.h
+ #undef TRANSPARENT
+ #endif
+#endif
+
 #include <gtkmm.h>
 #include <vector>
 
@@ -23,11 +30,13 @@ namespace ICON
 
         BKMARK_UPDATE,
         BKMARK,
+        BKMARK_BROKEN_SUBJECT,
         BKMARK_THREAD,
 
         UPDATE,
         NEWTHREAD,
         NEWTHREAD_HOUR,
+        BROKEN_SUBJECT,
         CHECK,
         DOWN,
         WRITE,
@@ -38,6 +47,9 @@ namespace ICON
 
         DIR,
         FAVORITE,
+        HIST,
+        HIST_BOARD,
+        HIST_CLOSE,
 
         BOARD,
         BOARD_UPDATE,
@@ -50,6 +62,7 @@ namespace ICON
 
         IMAGE,
         LINK,
+        INFO,
 
 #if GTKMMVER <= 240   // 2.4 以前は Gtk::Stock::MEDIA_PLAY が無い
         PLAY,
