@@ -52,6 +52,9 @@ ImageAdmin::ImageAdmin( const std::string& url )
     m_left.set_label( "<" );
     m_right.set_label( ">" );
 
+    m_left.set_focus_on_click( false );
+    m_right.set_focus_on_click( false );
+
     m_left.signal_pressed().connect( sigc::mem_fun( *this, &ImageAdmin::slot_press_left ) );
     m_right.signal_pressed().connect( sigc::mem_fun( *this, &ImageAdmin::slot_press_right ) );
     m_left.signal_released().connect( sigc::mem_fun( *this, &ImageAdmin::slot_release_left ) );
@@ -73,12 +76,18 @@ ImageAdmin::~ImageAdmin()
     std::cout << "ImageAdmin::~ImageAdmin\n";
 #endif 
 
+    close_window();
+}
+
+
+void ImageAdmin::save_session()
+{
+    Admin::save_session();
+
     // 開いているURLを保存
     SESSION::set_image_URLs( get_URLs() );
     SESSION::set_image_locked( get_locked() );
     SESSION::set_image_page( get_current_page() );
-
-    close_window();
 }
 
 
@@ -164,7 +173,7 @@ int ImageAdmin::get_tab_nums()
 //
 // 含まれているページのURLのリスト取得
 //
-std::list< std::string > ImageAdmin::get_URLs()
+const std::list< std::string > ImageAdmin::get_URLs()
 {
     std::list< std::string > urls;
     Gtk::Box_Helpers::BoxList::iterator it = m_iconbox.children().begin();
@@ -259,10 +268,14 @@ void ImageAdmin::command_local( const COMMAND_ARGS& command )
 
     else if( command.command  == "close_right_views" ) close_right_views( command.url );
 
+    else if( command.command  == "close_error_views" ) close_error_views( command.arg1 );
+
+    else if( command.command  == "close_noerror_views" ) close_noerror_views();
+
     else if( command.command  == "close_all_views" ) close_other_views( std::string() );
 
     // キャッシュに無いviewを削除
-    else if( command.command  == "close_nocached_views" ) close_nocached_views();
+    else if( command.command  == "close_nocached_views" ) close_error_views( "nocached" );
 
     // 画面のスクロール
     else if( command.command == "scroll_up" ){
@@ -324,7 +337,7 @@ void ImageAdmin::open_view( const COMMAND_ARGS& command )
 //
 // タブの切替え
 //
-void ImageAdmin::tab_left()
+void ImageAdmin::tab_left( const bool updated )
 {
     if( m_iconbox.children().size() == 1 ) return;
 
@@ -352,7 +365,7 @@ void ImageAdmin::tab_left()
 }
 
 
-void ImageAdmin::tab_right()
+void ImageAdmin::tab_right( const bool updated )
 {
     if( m_iconbox.children().size() == 1 ) return;
 
@@ -621,16 +634,61 @@ void ImageAdmin::close_right_views( const std::string& url )
 
 
 //
-// キャッシュに無い画像を閉じる
+// エラーになっている画像を閉じる
 //
-void ImageAdmin::close_nocached_views()
+void ImageAdmin::close_error_views( const std::string mode )
 {
+#ifdef _DEBUG
+    std::cout << "ImageAdmin::close_error_views\n";
+#endif
+
     Gtk::Box_Helpers::BoxList::iterator it = m_iconbox.children().begin();
     for(; it !=  m_iconbox.children().end(); ++it ){
+
         SKELETON::View* view = dynamic_cast< SKELETON::View* >( it->get_widget() );
         if( view ){
-            std::string url = view->get_url();
-            if( ! DBIMG::is_cached( url ) && DBIMG::get_code( url ) == HTTP_INIT ) set_command( "close_view", url );
+
+            const std::string url = view->get_url();
+
+            if( DBIMG::is_cached ( url ) ) continue;
+            if( mode != "all" && DBIMG::is_loading ( url ) ) continue;
+            if( DBIMG::is_wait ( url ) ) continue;
+
+            const int code = DBIMG::get_code( url );
+            if( ( code == HTTP_FORBIDDEN || code == HTTP_NOT_FOUND )  // 404,403 は無条件で閉じる
+                || ( mode == "notimeout" && code != HTTP_TIMEOUT && code != HTTP_TEMP_UNAV ) // timeout,503以外
+                || ( mode == "nocached"  && code == HTTP_INIT ) // キャッシュに無い(削除済み)の画像
+                || mode == "all"  // 読み込み中も含めて閉じる
+                ){
+                set_command( "close_view", url );
+                if( mode == "all" ) DBIMG::stop_load( url );
+            }
+        }
+    }
+}
+
+
+//
+// エラーでない画像を閉じる
+//
+void ImageAdmin::close_noerror_views()
+{
+#ifdef _DEBUG
+    std::cout << "ImageAdmin::close_noerror_views\n";
+#endif
+
+    Gtk::Box_Helpers::BoxList::iterator it = m_iconbox.children().begin();
+    for(; it !=  m_iconbox.children().end(); ++it ){
+
+        SKELETON::View* view = dynamic_cast< SKELETON::View* >( it->get_widget() );
+        if( view ){
+
+            const std::string url = view->get_url();
+
+            if( ! DBIMG::is_cached ( url ) ) continue;
+
+            const int code = DBIMG::get_code( url );
+            if( code == HTTP_OK ) set_command( "close_view", url );
         }
     }
 }
@@ -803,6 +861,9 @@ SKELETON::View* ImageAdmin::get_current_icon()
 //
 SKELETON::View* ImageAdmin::get_view( const std::string& url )
 {
+    SKELETON::View* view = get_current_view();
+    if( view && view->get_url() == url ) return view;
+
     std::list< SKELETON::View* >::iterator it_view;
     for( it_view = m_list_view.begin(); it_view != m_list_view.end(); ++it_view ){
         if( ( *it_view )->get_url() == url ) return ( *it_view );
@@ -931,7 +992,7 @@ void ImageAdmin::save_all()
     std::cout << "ImageAdmin::save_all\n";
 #endif
 
-    int overwrite = 0; // -1 なら全てNO、1ならすべてYES
+    int overwrite = Gtk::RESPONSE_NO;
 
     std::list< std::string > list_urls = get_URLs();
 
@@ -944,7 +1005,7 @@ void ImageAdmin::save_all()
 
         diag.hide();
 
-        std::string path_dir = diag.get_filename();
+        std::string path_dir = MISC::recover_path( diag.get_filename() );
         if( path_dir.empty() ) return;
         if( path_dir.c_str()[ path_dir.length()-1 ] != '/' ) path_dir += "/";
         
@@ -974,10 +1035,14 @@ void ImageAdmin::save_all()
                 if( CACHE::file_exists( path_to ) == CACHE::EXIST_FILE ){
 
                     // すべて上書き
-                    if( overwrite == 1 ){
+                    if( overwrite == SKELETON::OVERWRITE_YES_ALL ){
                         if( ! copy_file( url, path_from, path_to ) ) return;
                     }
-                    else if( overwrite != -1 ){
+
+                    // すべていいえ
+                    else if( overwrite == SKELETON::OVERWRITE_NO_ALL ){}
+
+                    else{
 
                         // ビューを切り替えてURLやステータス更新
                         switch_img( url );
@@ -986,24 +1051,19 @@ void ImageAdmin::save_all()
 
                         for(;;){
 
-                            SKELETON::MsgDiag mdiag( get_win(), "ファイルが存在します。ファイル名を変更して保存しますか？", 
-                                                     false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_NONE );
-                            mdiag.add_button( Gtk::Stock::NO, Gtk::RESPONSE_NO );
-                            mdiag.add_button( Gtk::Stock::YES, Gtk::RESPONSE_YES );
-                            mdiag.add_button( "上書き", Gtk::RESPONSE_YES + 100 );
-                            mdiag.add_button( "すべていいえ", Gtk::RESPONSE_NO + 200 );
-                            mdiag.add_button( "すべて上書き", Gtk::RESPONSE_YES + 200 );
+                            SKELETON::MsgOverwriteDiag mdiag( get_win() );
 
-                            int ret = mdiag.run();
+                            overwrite = mdiag.run();
                             mdiag.hide();
 
-                            switch( ret ){
+                            switch( overwrite ){
 
                                 // すべて上書き
-                                case Gtk::RESPONSE_YES + 200:
-                                    overwrite = 1;
+                                case SKELETON::OVERWRITE_YES_ALL:
+
                                     // 上書き
-                                case Gtk::RESPONSE_YES + 100:
+                                case SKELETON::OVERWRITE_YES:
+
                                     if( ! copy_file( url, path_from, path_to ) ) return;
                                     break;
 
@@ -1012,11 +1072,6 @@ void ImageAdmin::save_all()
                                     if( ! DBIMG::save( url, get_win(), path_to ) ) continue;
                                     break;
 
-                                    //  すべていいえ
-                                case Gtk::RESPONSE_NO + 200:
-                                    overwrite = -1;
-                                    break;
-
                                 default:
                                     break;
                             }
@@ -1031,7 +1086,11 @@ void ImageAdmin::save_all()
             }
 
         }
-        else MISC::ERRMSG( "can't create " + path_dir );
+        else{
+
+            SKELETON::MsgDiag mdiag( get_win(), path_dir + "\n\nの作成に失敗しました。\nハードディスクの容量やパーミッションなどを確認してください。\n\n画像保存をキャンセルしました。原因を解決してからもう一度保存を行ってください。" );
+            mdiag.run();
+        }
     }
 }
 
