@@ -13,9 +13,10 @@
 
 #include "config/globalconf.h"
 
+#include "control/controlid.h"
+
 #include "command.h"
 #include "httpcode.h"
-#include "controlid.h"
 #include "session.h"
 #include "global.h"
 
@@ -43,7 +44,9 @@ ImageViewMain::ImageViewMain( const std::string& url )
       m_scrwin( 0 ),
       m_length_prev( 0 ),
       m_show_status( false ),
-      m_show_label( false )
+      m_show_label( false ),
+      m_do_resizing( false ),
+      m_scrolled( false )
 {
 #ifdef _DEBUG    
     std::cout << "ImageViewMain::ImageViewMain : " << get_url() << std::endl;
@@ -72,6 +75,8 @@ ImageViewMain::ImageViewMain( const std::string& url )
 //
 // クロック入力
 //
+// アクティブ(表示されている)view以外にはクロックは来ないのに注意
+//
 void ImageViewMain::clock_in()
 {
     View::clock_in();
@@ -85,14 +90,35 @@ void ImageViewMain::clock_in()
         IMAGE::get_admin()->set_command( "set_status", get_url(), get_status() );
     }
 
+    // ロード待ち
+    if( is_wait() ){
+
+        // ロード待ち状態解除
+        if( ! get_img()->is_wait() ){
+
+            set_wait( false );
+
+            if( get_img()->is_loading() ){
+                set_loading( true  ); 
+                set_status( "読み込み中" );
+                if( m_show_label ) m_label.set_text( get_status() );
+            }
+
+            else{
+                set_loading( false );
+                show_view();
+                show_status();
+            }
+        }
+    }
+
     // ロード中
-    if( is_loading() ){
+    else if( is_loading() ){
 
         // 読み込みサイズの表示更新
         if( get_img()->is_loading() ) show_status();
 
         // ロード完了
-        // 次にclock_in()が呼ばれたら下のelseの中に入る
         else{
 
             set_loading( false ); 
@@ -160,7 +186,7 @@ void ImageViewMain::clock_in()
 //
 void ImageViewMain::show_instruct_diag()
 {
-    SKELETON::MsgCheckDiag mdiag( NULL, 
+    SKELETON::MsgCheckDiag mdiag( get_parent_win(), 
                                   "画像ビューからスレビューに戻る方法として\n\n(1) マウスジェスチャを使う\n(マウス右ボタンを押しながら左または下にドラッグして右ボタンを離す)\n\n(2) マウスの5ボタンを押す\n\n(3) Alt+x か h か ← を押す\n\n(4) ツールバーのスレビューアイコンを押す\n\n(5) 表示メニューからスレビューを選ぶ\n\nなどがあります。詳しくはオンラインマニュアルを参照してください。",
                                   "今後表示しない(_D)"
         );
@@ -207,6 +233,7 @@ void ImageViewMain::remove_label()
 void ImageViewMain::show_view()
 {
     if( is_loading() ) return;
+    if( is_wait() ) return;
 
 #ifdef _DEBUG
     std::cout << "ImageViewMain::show_view url = " << get_url() << std::endl;
@@ -230,15 +257,26 @@ void ImageViewMain::show_view()
 
     remove_label();
 
-    // 読み込み中        
-    if( get_img()->is_loading() ){
+    // ロード待ち、又は読み込み中        
+    if( get_img()->is_wait() || get_img()->is_loading() ){
 
+        if( get_img()->is_wait() ){
 #ifdef _DEBUG
-        std::cout << "now loading\n";
-#endif    
-        set_loading( true );
+            std::cout << "wait\n";
+#endif
+            set_wait( true );
+            set_loading( false );
+            set_status( "待機中" );
+        }
+        else{
+#ifdef _DEBUG
+            std::cout << "loading\n";
+#endif
+            set_wait( false );
+            set_loading( true );
+            set_status( "読み込み中" );
+        }
         m_length_prev = 0;
-        set_status( "loading..." );
         m_show_status = true; // viewがアクティブになった時点でステータス表示
 
         set_label();
@@ -257,7 +295,9 @@ void ImageViewMain::show_view()
     // エラー
     else{
 
-        set_status( get_img()->get_str_code() );
+        if( ! get_img()->get_str_code().empty() ) set_status( get_img()->get_str_code() );
+        else set_status( "画像情報が存在しません。再読み込みして下さい" );
+
         m_show_status = true; // viewがアクティブになった時点でステータス表示
 
         set_label();
@@ -273,7 +313,7 @@ void ImageViewMain::show_view()
 //
 void ImageViewMain::show_status()
 {
-    if( ! is_loading() ){
+    if( ! is_loading() && ! is_wait() ){
 
         // 画像が表示されていたら画像情報
         if( get_imagearea() ){
@@ -282,7 +322,7 @@ void ImageViewMain::show_status()
             ss << get_img()->get_width() << " x " << get_img()->get_height();
             if( get_img()->get_width() )
                 ss << " (" << get_img()->get_size() << " %)";
-            ss << " " << get_img()->total_length()/1024 << " kb ";
+            ss << " " << get_img()->total_length()/1024 << " K ";
             if( get_img()->is_protected() ) ss << " キャッシュ保護されています";
 
             set_status( ss.str() );
@@ -291,8 +331,7 @@ void ImageViewMain::show_status()
         // エラー(ネットワーク系)
         else if( get_img()->get_code() != HTTP_OK ) set_status( get_img()->get_str_code() );
 
-        // ステータス標示
-        IMAGE::get_admin()->set_command( "set_status", get_url(), get_status() );
+        m_show_status = true; // viewがアクティブになった時点でステータス表示
         if( m_show_label ) m_label.set_text( get_status() );
 
 #ifdef _DEBUG
@@ -301,7 +340,7 @@ void ImageViewMain::show_status()
     }
 
     // ロード中
-    else{
+    else if( is_loading() ){
 
         // 読み込みサイズが更新した場合
         if( m_length_prev != get_img()->current_length() ){
@@ -312,8 +351,7 @@ void ImageViewMain::show_status()
             snprintf( tmpstr, 256, "%zd k / %zd k", m_length_prev/1024, get_img()->total_length()/1024 );
             set_status( tmpstr );
 
-            // ステータス標示
-            IMAGE::get_admin()->set_command( "set_status", get_url(), get_status() );
+            m_show_status = true; // viewがアクティブになった時点でステータス表示
             if( m_show_label ) m_label.set_text( get_status() );
 
 #ifdef _DEBUG
@@ -347,6 +385,12 @@ bool ImageViewMain::slot_button_press( GdkEventButton* event )
     // ドラッグして画像移動するときの起点
     m_x_motion = event->x_root;
     m_y_motion = event->y_root;
+    m_scrolled = false;
+
+    // ボタンをリリースした時に大きさを変更
+    m_do_resizing = false;
+    if( ! is_loading() && ! is_wait()
+        && get_control().button_alloted( event, CONTROL::ResizeImageButton ) ) m_do_resizing = true;
 
     return true;
 }
@@ -394,6 +438,8 @@ bool ImageViewMain::slot_motion_notify( GdkEventMotion* event )
 
             if( vadj ) vadj->set_value(
                 MAX( vadj->get_lower(), MIN( vadj->get_upper() - vadj->get_page_size(), vadj->get_value() - dy ) ) );
+
+            m_scrolled = true;
         }
     }
 
@@ -461,3 +507,28 @@ void ImageViewMain::scroll_right()
     hadjust->set_value(  MIN( hadjust->get_upper() - hadjust->get_page_size(),
                               hadjust->get_value() + hadjust->get_step_increment() ) );
 }
+
+
+//
+// viewの操作
+//
+const bool ImageViewMain::operate_view( const int control )
+{
+    // スクロールしたときはキャンセル
+    if( m_scrolled ){
+        m_scrolled = false;
+        return false;
+    }
+
+    int cntl = control;
+
+    if( m_do_resizing ){
+
+        m_do_resizing = false;
+
+        if( get_img()->get_size() == 100 ) cntl = CONTROL::ZoomFitImage;
+        else cntl = CONTROL::OrgSizeImage;
+    }
+
+    return ImageViewBase::operate_view( cntl );
+}
