@@ -25,6 +25,9 @@ namespace IMAGE
         int m_pre_height;
         int m_redraw_count;
 
+        bool m_do_resizing;
+        bool m_scrolled;
+
       public:
         ImageViewMain( const std::string& url );
 
@@ -35,6 +38,8 @@ namespace IMAGE
         virtual void scroll_left();
         virtual void scroll_right();
 
+        virtual const bool operate_view( const int control );
+
       protected:
         virtual void show_status();
 
