@@ -80,6 +80,8 @@ namespace IMAGE
         // SKELETON::View の関数のオーバロード
         //
 
+        virtual void save_session(){}
+
         // 親ウィンドウを取得
         virtual Gtk::Window* get_parent_win();
 
@@ -139,6 +141,7 @@ namespace IMAGE
         void slot_resize_image( int size );
         void slot_lock();
         void slot_open_browser();
+        void slot_open_cache_browser();
         void slot_open_ref();
         void slot_copy_url();
         void slot_save_all();
@@ -149,6 +152,9 @@ namespace IMAGE
         void slot_close_left_views();
         void slot_close_right_views();
         void slot_close_error_views();
+        void slot_close_notimeout_error_views();
+        void slot_close_all_error_views();
+        void slot_close_noerror_views();
         void slot_close_all_views();
         void slot_usrcmd( int num );
     };
