@@ -5,7 +5,21 @@
 #ifndef _JDTHREAD_H
 #define _JDTHREAD_H
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
+#ifdef USE_GTHREAD
+#include <gtkmm.h>
+#define JDTH_TYPE Glib::Thread*
+#define JDTH_ISRUNNING( pth ) ( ( pth ) != NULL )
+#define JDTH_CLEAR( pth ) ( ( pth ) = NULL )
+#else
 #include <pthread.h>
+#define JDTH_TYPE pthread_t
+#define JDTH_ISRUNNING( pth ) ( pth )
+#define JDTH_CLEAR( pth ) ( pth = 0 )
+#endif
 
 typedef void* ( *STARTFUNC )( void * );
 
@@ -24,14 +38,18 @@ namespace JDLIB
 
     class Thread
     {
-        pthread_t m_thread;
+        JDTH_TYPE m_thread;
 
-      public:
+#ifdef USE_GTHREAD
+        static void slot_wrapper( STARTFUNC func, void* arg );
+#endif
+
+    public:
 
         Thread();
         virtual ~Thread();
 
-        const bool is_running() const { return ( m_thread ); }
+        const bool is_running() const { return JDTH_ISRUNNING( m_thread ); }
 
         // スレッド作成
         const bool create( STARTFUNC func , void * arg, const bool detach, const int stack_kbyte = DEFAULT_STACKSIZE );
