@@ -7,8 +7,10 @@
 #include "miscmsg.h"
 #include "jdiconv.h"
 #include "jdregex.h"
+#include "hkana.h"
 
 #include "dbtree/spchar_decoder.h"
+#include "dbtree/node.h"
 
 #include <sstream>
 #include <cstring>
@@ -401,7 +403,12 @@ const std::string MISC::remove_str( const std::string& str, const std::string& s
 const std::string MISC::remove_str_regex( const std::string& str1, const std::string& query )
 {
     JDLIB::Regex regex;
-    if( ! regex.exec( query, str1 ) ) return std::string();
+    const size_t offset = 0;
+    const bool icase = false;
+    const bool newline = true;
+    const bool usemigemo = false;
+    const bool wchar = false;
+    if( ! regex.exec( query, str1, offset, icase, newline, usemigemo, wchar ) ) return std::string();
     return MISC::remove_str( str1, regex.str( 0 ) );
 }
 
@@ -539,14 +546,14 @@ const int MISC::count_chr( const std::string& str, const char chr )
 //
 // 戻り値: 数値
 //
-const int MISC::str_to_uint( const char* str, unsigned int& dig, unsigned int& n )
+const int MISC::str_to_uint( const char* str, size_t& dig, size_t& n )
 {
     int out = 0;
     dig = 0;
     n = 0;
     while( *str != '\0' ){
 
-        unsigned char in = (*str);
+        const unsigned char in = (*str);
         
         if( '0' <=  in && in <= '9' ){
 
@@ -557,9 +564,11 @@ const int MISC::str_to_uint( const char* str, unsigned int& dig, unsigned int& n
         }
 
         else{
+
+            const unsigned char in2 = (* ( str +1 ));
+            const unsigned char in3 = (* ( str +2 ));
+
             // utf-8
-            unsigned char in2 = (* ( str +1 ));
-            unsigned char in3 = (* ( str +2 ));
             if( in == 0xef && in2 == 0xbc && ( 0x90 <= in3 && in3 <= 0x99 ) ){
                 out = out*10 + ( in3 - 0x90 );
                 ++dig;
@@ -599,24 +608,25 @@ const std::string MISC::intlisttostr( const std::list< int >& list_num )
     bool comma = false;
     int num_from = *it;
     int num_to = -1;
-    ++it;
+    int i = 0;
     for(;;){
 
-        int num = *it;
-        if( num_from + 1 != num || it == list_num.end() ){
-                
+        ++i;
+        ++it;
+        const int num = *it;
+        if( num_from + i != num || it == list_num.end() ){
+
             if( comma ) comment << ",";
             comment << num_from;
             if( num_to != -1 ) comment << "-" << num_to;
             num_from = num;
             num_to = -1;
+            i = 0;
             comma = true;
 
             if( it == list_num.end() ) break;
         }
         else num_to = num;
-
-        ++it;
     }
 
     return comment.str();
@@ -644,11 +654,11 @@ const size_t MISC::chrtobin( const char* chr_in, char* chr_out )
         chr_out[b] <<= 4;
 
         // 0(0x30)〜9(0x39)
-        if( ( chr - 0x30 ) < 0x0A ) chr_out[b] |= chr - 0x30;
+        if( (unsigned char)( chr - 0x30 ) < 10 ) chr_out[b] |= chr - 0x30;
         // A(0x41)〜F(0x46)
-        else if( ( chr - 0x41 ) < 0x06 ) chr_out[b] |= chr - 0x37;
+        else if( (unsigned char)( chr - 0x41 ) < 6 ) chr_out[b] |= chr - 0x37;
         // a(0x61)〜f(0x66)
-        else if( ( chr - 0x61 ) < 0x06 ) chr_out[b] |= chr - 0x57;
+        else if( (unsigned char)( chr - 0x61 ) < 6 ) chr_out[b] |= chr - 0x57;
         // その他
         else break;
 
@@ -683,6 +693,147 @@ const std::string MISC::cut_str( const std::string& str, const unsigned int maxs
 }
 
 
+//
+// 正規表現のメタ文字が含まれているか
+//
+// escape == true ならエスケープを考慮 (例)  escape == true なら \+ → \+ のまま、falseなら \+ → \\\+
+//
+
+#define REGEX_METACHARS ".+*?^$|{}[]()\\"
+
+const bool MISC::has_regex_metachar( const std::string& str, const bool escape )
+{
+    const char metachars[] = REGEX_METACHARS;
+    const size_t str_length = str.length();
+
+    for( size_t pos = 0; pos < str_length; ++pos ){
+
+        if( escape && str[ pos ] == '\\' ){
+
+            int i = 0;
+            while( metachars[ i ] != '\0' ){
+
+                if( str[ pos + 1 ] == metachars[ i ]  ) break;
+                ++i;
+            }
+
+            if( metachars[ i ] == '\0' ) return true;
+
+            ++pos;
+        }
+        else{
+
+            int i = 0;
+            while( metachars[ i ] != '\0' ){
+
+                if( str[ pos ] == metachars[ i ] ) return true;
+                ++i;
+            }
+        }
+    }
+
+    return false;
+}
+
+
+//
+// 正規表現のメタ文字をエスケープ
+//
+// escape == true ならエスケープを考慮 (例)  escape == true なら \+ → \+ のまま、falseなら \+ → \\\+
+//
+const std::string MISC::regex_escape( const std::string& str, const bool escape )
+{
+    if( ! has_regex_metachar( str, escape ) ) return str;
+
+#ifdef _DEBUG
+    std::cout << "MISC::regex_escape" << std::endl;
+#endif
+
+    std::string str_out;
+
+    const char metachars[] = REGEX_METACHARS;
+    const size_t str_length = str.length();
+
+    for( size_t pos = 0; pos < str_length; ++pos ){
+
+        if( escape && str[ pos ] == '\\' ){
+
+            int i = 0;
+            while( metachars[ i ] != '\0' ){
+
+                if( str[ pos + 1 ] == metachars[ i ]  ) break;
+                ++i;
+            }
+
+            if( metachars[ i ] == '\0' ) str_out += '\\';
+            else{
+                str_out += str[ pos ];
+                ++pos;
+            }
+        }
+        else{
+
+            int i = 0;
+            while( metachars[ i ] != '\0' ){
+
+                if( str[ pos ] == metachars[ i ] ){
+                    str_out += '\\';
+                    break;
+                }                    
+                ++i;
+            }
+        }
+
+        str_out += str[ pos ];
+    }
+
+#ifdef _DEBUG
+    std::cout << str << " -> " << str_out << std::endl;
+#endif
+
+    return str_out;
+}
+
+
+//
+// 正規表現のメタ文字をアンエスケープ
+//
+const std::string MISC::regex_unescape( const std::string& str )
+{
+#ifdef _DEBUG
+    std::cout << "MISC::regex_unescape" << std::endl;
+#endif
+
+    std::string str_out;
+
+    const char metachars[] = REGEX_METACHARS;
+    const size_t str_length = str.length();
+
+    for( size_t pos = 0; pos < str_length; ++pos ){
+
+        if( str[ pos ] == '\\' ){
+
+            int i = 0;
+            while( metachars[ i ] != '\0' ){
+
+                if( str[ pos + 1 ] == metachars[ i ] ){
+                    ++pos;
+                    break;
+                }
+                ++i;
+            }
+        }
+
+        str_out += str[ pos ];
+    }
+
+#ifdef _DEBUG
+    std::cout << str << " -> " << str_out << std::endl;
+#endif
+
+    return str_out;
+}
+
 
 //
 // HTMLエスケープ
@@ -729,10 +880,9 @@ const std::string MISC::html_escape( const std::string& str, const bool include_
             const int bufsize = 64;
             char out_char[ bufsize ];
             int n_in, n_out;
-            DBTREE::decode_char( str.c_str() + pos, n_in, out_char, n_out );
-
-            if( n_out ) str_out += tmpchar;
-            else str_out += "&amp;";
+            const int type = DBTREE::decode_char( str.c_str() + pos, n_in, out_char, n_out, false );
+            if( type == DBTREE::NODE_NONE ) str_out += "&amp;";
+            else str_out += tmpchar;
         }
         else if( tmpchar == '\"' ) str_out += "&quot;";
         else if( tmpchar == '<' ) str_out += "&lt;";
@@ -767,7 +917,7 @@ const std::string MISC::html_unescape( const std::string& str )
         const int bufsize = 64;
         char out_char[ bufsize ];
         int n_in, n_out;
-        DBTREE::decode_char( str.c_str() + pos, n_in, out_char, n_out );
+        DBTREE::decode_char( str.c_str() + pos, n_in, out_char, n_out, false );
 
         if( n_out ){
             str_out += out_char;
@@ -993,6 +1143,11 @@ const std::string MISC::url_encode( const char* str, const size_t n )
 }
 
 
+const std::string MISC::url_encode( const std::string& str )
+{
+    return url_encode( str.c_str(), str.length() );
+}
+
 
 //
 // 文字コード変換して url エンコード
@@ -1003,10 +1158,8 @@ const std::string MISC::charset_url_encode( const std::string& str, const std::s
 {
     if( charset.empty() || charset == "UTF-8" ) return MISC::url_encode( str.c_str(), str.length() );
 
-    std::string str_enc = MISC::Iconv( str, "UTF-8", charset );
-    std::string str_encoded = MISC::url_encode( str_enc.c_str(), strlen( str_enc.c_str() ) );
-
-    return str_encoded;
+    const std::string str_enc = MISC::Iconv( str, "UTF-8", charset );
+    return  MISC::url_encode( str_enc.c_str(), str_enc.length() );
 }
 
 
@@ -1089,7 +1242,7 @@ const std::string MISC::Iconv( const std::string& str, const std::string& coding
     JDLIB::Iconv* libiconv = new JDLIB::Iconv( coding_from, coding_to );
     int byte_out;
 
-    std::string str_enc = libiconv->convert( str_bk, strlen( str_bk ), byte_out );
+    const std::string str_enc = libiconv->convert( str_bk, strlen( str_bk ), byte_out );
 
     delete libiconv;
     free( str_bk );
@@ -1098,13 +1251,135 @@ const std::string MISC::Iconv( const std::string& str, const std::string& coding
 }
 
 
+//
+// 「&#数字;」形式の数字参照文字列の中の「数字」部分の文字列長
+//
+// in_char: 入力文字列、in_char[0] == "&" && in_char[1] == "#" であること
+// offset : 開始位置が返る
+//
+// 戻り値 : 「&#数字;」の中の数字の文字列の長さ、変換出来ないときは -1
+//
+// 例 : &#9999; なら 戻り値 = 4、 offset = 2
+//
+const int MISC::spchar_number_ln( const char* in_char, int& offset )
+{
+    int lng;
+    offset = 2;
+
+    // offset == 2 なら 10 進数、3 なら16進数
+    if( in_char[ offset ] == 'x' || in_char[ offset ] == 'X' ) ++offset;
+
+    // 桁数取得(最大4桁)
+    if( in_char[ offset ] == ';' ) return -1;
+    else if( in_char[ offset +1 ] == ';' ) lng = 1;
+    else if( in_char[ offset +2 ] == ';' ) lng = 2;
+    else if( in_char[ offset +3 ] == ';' ) lng = 3;
+    else if( in_char[ offset +4 ] == ';' ) lng = 4;
+    else if( in_char[ offset +5 ] == ';' ) lng = 5;
+    else return -1;
+
+    // デコード可能かチェック
+
+    // 10 進数
+    if( offset == 2 ){
+
+        for( int i = 0; i < lng; ++i ){
+            if( in_char[ offset + i ] < '0' || in_char[ offset + i ] > '9' ) return -1;
+        }
+    }
+
+    // 16 進数
+    else{
+
+        for( int i = 0; i < lng; ++i ){
+            if(
+                ! (
+                    ( in_char[ offset + i ] >= '0' && in_char[ offset + i ] <= '9' )
+                    || ( in_char[ offset + i ] >= 'a' && in_char[ offset + i ] <= 'f' )
+                    || ( in_char[ offset + i ] >= 'A' && in_char[ offset + i ] <= 'F' )
+                    )
+                ) return -1;
+        }
+    }
+
+    return lng;
+}
+
+
+//
+// 「&#数字;」形式の数字参照文字列を数字(int)に変換する
+//
+// 最初に MISC::spchar_number_ln() を呼び出して offset と lng を取得すること
+//
+// in_char: 入力文字列、in_char[0] == "&" && in_char[1] == "#" であること
+// offset : spchar_number_ln() の戻り値
+// lng : spchar_number_ln() の戻り値
+//
+// 戻り値 : 「&#数字;」の中の数字(int型)
+//
+const int MISC::decode_spchar_number( const char* in_char, const int offset, const int lng )
+{
+    char str_num[ 16 ];
+
+    memcpy( str_num, in_char + offset, lng );
+    str_num[ lng ] = '\0';
+
+#ifdef _DEBUG
+    std::cout << "MISC::decode_spchar_number offset = " << offset << " lng = " << lng << " str = " << str_num << std::endl;
+#endif
+
+    int num = 0;
+    if( offset == 2 ) num = atoi( str_num );
+    else num = strtol( str_num, NULL, 16 );
+
+    return num;
+}
+
+
+//
+// str に含まれる「&#数字;」形式の数字参照文字列を全てユニーコード文字に変換する
+//
+const std::string MISC::decode_spchar_number( const std::string& str )
+{
+    std::string str_out;
+    const size_t str_length = str.length();
+
+    for( size_t i = 0; i < str_length ; ++i ){
+
+        if( str[ i ] == '&' && str[ i + 1 ] == '#' ){
+
+            int offset;
+            const int lng = MISC::spchar_number_ln( str.c_str()+i, offset );
+            if( lng == -1 ){
+                str_out += str[ i ];
+                continue;
+            }
+
+            const int num = MISC::decode_spchar_number( str.c_str()+i, offset, lng );
+
+            char out_char[ 64 ];
+            const int n_out = MISC::ucs2toutf8( num, out_char );
+            if( ! n_out ){
+                str_out += str[ i ];
+                continue;
+            }
+
+            for( int j = 0; j < n_out; ++j ) str_out += out_char[ j ];
+            i += offset + lng;
+        }
+        else str_out += str[ i ];
+    }
+
+    return str_out;
+}
+
 
 //
 // utf-8 -> ucs2 変換
 //
 // 入力 : utfstr 入力文字 (UTF-8)
 //
-// 出力 :  byte  長さ(バイト) utfstr が ascii なら 1, UTF-8 なら 2 or 3 を入れて返す
+// 出力 :  byte  長さ(バイト) utfstr が ascii なら 1, UTF-8 なら 2 or 3 or 4 を入れて返す
 //
 // 戻り値 : ucs2
 //
@@ -1115,25 +1390,25 @@ const int MISC::utf8toucs2( const char* utfstr, int& byte )
 
     if( utfstr[ 0 ] == '\0' ) return '\0';
     
-    if( ( ( unsigned char ) utfstr[ 0 ] & 0x80 ) == 0 ){ // ascii
-        byte = 1;
-        ucs2 =  utfstr[ 0 ];
-    }
-
-    else if( ( ( unsigned char ) utfstr[ 0 ] & 0x20 ) == 0 ){
-        byte = 2;
-        ucs2 = utfstr[ 0 ] & 0x1f;
-        ucs2 = ( ucs2 << 6 ) + ( utfstr[ 1 ] & 0x3f );
-    }
-
-    else if( ( ( unsigned char ) utfstr[ 0 ] & 0x10 ) == 0 ){
+    else if( ( ( unsigned char ) utfstr[ 0 ] & 0xf0 ) == 0xe0 ){
         byte = 3;
         ucs2 = utfstr[ 0 ] & 0x0f;
         ucs2 = ( ucs2 << 6 ) + ( utfstr[ 1 ] & 0x3f );
         ucs2 = ( ucs2 << 6 ) + ( utfstr[ 2 ] & 0x3f );        
     }
 
-    else{
+    else if( ( ( unsigned char ) utfstr[ 0 ] & 0x80 ) == 0 ){ // ascii
+        byte = 1;
+        ucs2 =  utfstr[ 0 ];
+    }
+
+    else if( ( ( unsigned char ) utfstr[ 0 ] & 0xe0 ) == 0xc0 ){
+        byte = 2;
+        ucs2 = utfstr[ 0 ] & 0x1f;
+        ucs2 = ( ucs2 << 6 ) + ( utfstr[ 1 ] & 0x3f );
+    }
+
+    else if( ( ( unsigned char ) utfstr[ 0 ] & 0xf8 ) == 0xf0 ){
         byte = 4;
         ucs2 = utfstr[ 0 ] & 0x07;
         ucs2 = ( ucs2 << 6 ) + ( utfstr[ 1 ] & 0x3f );
@@ -1141,6 +1416,13 @@ const int MISC::utf8toucs2( const char* utfstr, int& byte )
         ucs2 = ( ucs2 << 6 ) + ( utfstr[ 3 ] & 0x3f );        
     }
 
+    // 不正なUTF8
+    else {
+        byte = 1;
+        ucs2 =  utfstr[ 0 ];
+        ERRMSG( "MISC::utf8toucs2 : invalid code = " + MISC::itostr( ucs2 ) );
+    }
+
     return ucs2;
 }
 
@@ -1201,6 +1483,58 @@ const int MISC::get_ucs2mode( const int ucs2 )
     return UCS2MODE_OTHER;
 }
 
+//
+// WAVEDASHなどのWindows系UTF-8文字をUnix系文字と相互変換
+//
+const std::string MISC::utf8_fix_wavedash( const std::string& str, const int mode )
+{
+    // WAVE DASH 問題
+    const size_t size = 4;
+    const char Win[size][4] = {
+        { 0xef, 0xbd, 0x9e, '\0' }, // FULLWIDTH TILDE (U+FF5E)
+        { 0xe2, 0x80, 0x95, '\0' }, // HORIZONTAL BAR (U+2015)
+        { 0xe2, 0x88, 0xa5, '\0' }, // PARALLEL TO (U+2225)
+        { 0xef, 0xbc, 0x8d, '\0' }  // FULLWIDTH HYPHEN-MINUS (U+FF0D)
+    };
+    const char Unix[size][4] = {
+        { 0xe3, 0x80, 0x9c, '\0' }, // WAVE DASH (U+301C)
+        { 0xe2, 0x80, 0x94, '\0' }, // EM DASH(U+2014)
+        { 0xe2, 0x80, 0x96, '\0' }, // DOUBLE VERTICAL LINE (U+2016)
+        { 0xe2, 0x88, 0x92, '\0' }  // MINUS SIGN (U+2212)
+    };
+    
+    std::string ret(str);
+
+    if( mode == WINtoUNIX ){
+
+        for( size_t i = 0; i < ret.length(); i++ ) {
+            for( size_t s = 0; s < size; s++ ) {
+                if( ret[ i ] != Win[ s ][ 0 ] || ret[ i+1 ] != Win[ s ][ 1 ] || ret[ i+2 ] != Win[ s ][ 2 ] )
+                    continue;
+                for( size_t t = 0; t < 3; t++ )
+                    ret[ i+t ] = Unix[ s ][ t ];
+                i += 2;
+                break;
+            }
+        }
+
+    }else{
+   
+        for( size_t i = 0; i < ret.length(); i++ ) {
+            for( size_t s = 0; s < size; s++ ) {
+                if( ret[ i ] != Unix[ s ][ 0 ] || ret[ i+1 ] != Unix[ s ][ 1 ] || ret[ i+2 ] != Unix[ s ][ 2 ] )
+                    continue;
+                for( size_t t = 0; t < 3; t++ )
+                    ret[ i+t ] = Win[ s ][ t ];
+                i += 2;
+                break;
+            }
+        }
+    }
+
+    return ret;
+}
+
 
 //
 // str を大文字化
@@ -1312,5 +1646,209 @@ const std::string MISC::getenv_limited( const char *name, const size_t size )
 
     strncpy( env, getenv( name ), size );
 
+#ifdef _WIN32
+    return recover_path( Glib::locale_to_utf8( std::string( env ) ) );
+#else
     return std::string( env );
+#endif
+}
+
+
+//
+// pathセパレータを / に置き換える
+//
+const std::string MISC::recover_path( const std::string& str )
+{
+#ifdef _WIN32
+    // Windowsのpathセパレータ \ を、jdの / に置き換える
+    std::string ret( str );
+    for (int i=ret.length()-1; i>=0; i--)
+        if (ret[ i ] == '\\')
+            ret[ i ] = '/';
+    return ret;
+#else
+    return str;
+#endif
+}
+
+const std::list< std::string > MISC::recover_path( const std::list< std::string >& list_str )
+{
+#ifdef _WIN32
+    std::list< std::string > list_ret;
+    std::list< std::string >::const_iterator it = list_str.begin();
+    for( ; it != list_str.end() ; ++it )
+        list_ret.push_back( MISC::recover_path( *it ) );
+    return list_ret;
+#else
+    return list_str;
+#endif
+}
+
+
+
+//
+// 文字列(utf-8)に全角英数字が含まれるか判定する
+//
+const bool MISC::has_widechar( const char* str )
+{
+    while( *str != '\0' ){
+
+        const unsigned char in = *str;
+
+        if( ( in & 0xf0 ) == 0xe0 ){
+
+            if( in == 0xef ){
+
+                const unsigned char in2 = * ( str + 1 );
+                const unsigned char in3 = * ( str + 2 );
+
+                if( in2 == 0xbc ){
+
+                    // 全角数字
+                    if( 0x90 <= in3 && in3 <= 0x99 ) return true;
+
+                    // 全角大文字
+                    else if( 0xa1 <= in3 && in3 <= 0xba ) return true;
+                }
+
+                //  全角小文字
+                else if( in2 == 0xbd && ( 0x81 <= in3 && in3 <= 0x9a ) ) return true;
+
+                // 半角かな
+                else if( ( in2 == 0xbd && ( 0xa1 <= in3 && in3 <= 0xbf ) )
+                         || ( in2 == 0xbe && ( 0x80 <= in3 && in3 <= 0x9f ) ) ) return true;
+            }
+
+            str += 3;
+        }
+
+        else if( ( in & 0xe0 ) == 0xc0 ) str += 2;
+
+        else if( ( in & 0xf8 ) == 0xf0 ) str += 4;
+
+        else ++str;
+    }
+
+    return false;
+}
+
+
+//
+// 全角英数字(str1) -> 半角英数字(str2)
+//
+// table_pos : 置き換えた文字列の位置
+// n : str2 と table_pos のバッファサイズ
+//
+void MISC::asc( const char* str1, char* str2, int* table_pos, const size_t n )
+{
+    const size_t mrg = 18;
+    size_t pos = 0;
+    size_t pos2 = 0;
+
+    while( pos2 < ( n - mrg ) && *( str1 + pos ) != '\0' ){
+
+        const unsigned char in = *( str1 + pos );
+
+        if( in == 0xef ){
+
+            const unsigned char in2 = * ( str1 + pos + 1 );
+            const unsigned char in3 = * ( str1 + pos + 2 );
+
+            if( in2 == 0xbc ){
+
+                //  全角数字
+                if( 0x90 <= in3 && in3 <= 0x99 ){
+
+                    str2[ pos2 ] = '0' + in3 - 0x90;;
+                    table_pos[ pos2 ] = pos;
+                    pos += 3;
+                    ++pos2;
+                    continue;
+                }
+
+                //  全角大文字
+                else if( 0xa1 <= in3 && in3 <= 0xba ){
+
+                    str2[ pos2 ] = 'A' + in3 - 0xa1;
+                    table_pos[ pos2 ] = pos;
+
+                    pos += 3;
+                    ++pos2;
+                    continue;
+                }
+            }
+
+            //  全角小文字
+            else if( in2 == 0xbd && ( 0x81 <= in3 && in3 <= 0x9a ) ){
+
+                str2[ pos2 ] = 'a' + in3 - 0x81;
+                table_pos[ pos2 ] = pos;
+
+                pos += 3;
+                ++pos2;
+                continue;
+            }
+
+            // 半角かな
+            else if( ( in2 == 0xbd && ( 0xa1 <= in3 && in3 <= 0xbf ) )
+                     || ( in2 == 0xbe && ( 0x80 <= in3 && in3 <= 0x9f ) ) ){
+
+                bool flag_hkana = false;
+                bool dakuten = false;
+                size_t i = 0;
+
+                // 濁点、半濁点
+                const unsigned char in4 = * ( str1 + pos + 3 );
+                const unsigned char in5 = * ( str1 + pos + 4 );
+                if( in4 == 0xef && in5 == 0xbe ){
+
+                    const unsigned char in6 = * ( str1 + pos + 5 );
+
+                    // 濁点
+                    if( in6 == 0x9e ){
+                        dakuten = true;
+                        i = 61;
+                    }
+
+                    // 半濁点
+                    else if( in6 == 0x9f ){
+                        dakuten = true;
+                        i = 61 + 21;
+                    }
+                }
+
+                while( !flag_hkana && hkana_table1[ i ][ 0 ][ 0 ] != '\0' ){
+
+                    if( in == hkana_table1[ i ][ 0 ][ 0 ] && in2 == hkana_table1[ i ][ 0 ][ 1 ] && in3 == hkana_table1[ i ][ 0 ][ 2 ] ){
+
+                        str2[ pos2 ] = hkana_table1[ i ][ 1 ][ 0 ];
+                        str2[ pos2 +1 ] = hkana_table1[ i ][ 1 ][ 1 ];
+                        str2[ pos2 +2 ] = hkana_table1[ i ][ 1 ][ 2 ];
+                        table_pos[ pos2 ] = pos;
+
+                        pos += 3;
+                        if( dakuten ) pos += 3;
+                        pos2 += 3;
+                        flag_hkana = true;
+                    }
+                    ++i;
+                }
+                if( flag_hkana ) continue;
+            }
+        }
+
+        str2[ pos2 ] = str1[ pos ];
+        table_pos[ pos2 ] = pos;
+
+        ++pos;
+        ++pos2;
+    }
+
+    if( pos2 >= ( n - mrg ) ){
+        ERRMSG( "MISC::asc : buffer overflow." );
+        pos2 = ( n - mrg ) - 1;
+    }
+
+    table_pos[ pos2 ] = pos;
+    str2[ pos2 ] = '\0';
 }
