@@ -157,15 +157,6 @@ void Core::slot_reload_list()
 }
 
 
-//
-// お気に入り保存
-//
-void Core::slot_save_favorite()
-{
-    CORE::core_set_command( "save_favorite","" );
-}
-
-
 //
 // 終了
 //
@@ -187,6 +178,7 @@ void Core::slot_toggle_since( const int mode )
 #endif
 
     SESSION::set_col_since_time( mode );
+    DBTREE::reset_all_since_date();
     BOARD::get_admin()->set_command( "relayout_all" );    
 }
 
@@ -203,12 +195,30 @@ void Core::slot_toggle_write( const int mode )
 #endif
 
     SESSION::set_col_write_time( mode );
+    DBTREE::reset_all_write_date();
     BOARD::get_admin()->set_command( "relayout_all" );    
 }
 
 
 //
-// ツールバーの表示モード
+// メインツールバー表示切り替え
+//
+void Core::slot_toggle_toolbarmain()
+{
+    if( SESSION::is_booting() ) return;
+    if( ! m_enable_menuslot ) return;
+
+    pack_widget( true );
+    SESSION::set_show_main_toolbar( ! SESSION::get_show_main_toolbar() );
+    pack_widget( false );
+
+    restore_focus( true, false );
+
+}
+
+
+//
+// メインツールバーの表示位置
 //
 void Core::slot_toggle_toolbarpos( const int pos )
 {
@@ -219,15 +229,15 @@ void Core::slot_toggle_toolbarpos( const int pos )
     std::cout << "Core::slot_toggle_toolbarpos pos = " << pos << " / " << SESSION::toolbar_pos() << std::endl;
 #endif
 
-    pack_widget( true );
+    if( ! SESSION::get_show_main_toolbar() ) SESSION::set_toolbar_pos( pos );
+    else{
 
-    // 表示切り替え
-    if( SESSION::toolbar_pos() == pos ) SESSION::set_toolbar_pos( SESSION::TOOLBAR_POS_NOT ); // 隠す
-    else SESSION::set_toolbar_pos( pos );
+        pack_widget( true );
+        SESSION::set_toolbar_pos( pos );
+        pack_widget( false );
 
-    pack_widget( false );
-
-    restore_focus( true, false );
+        restore_focus( true, false );
+    }
 }
 
 
@@ -342,6 +352,18 @@ void Core::slot_toggle_v3pane()
 }
 
 
+//
+// フルスクリーン
+//
+void Core::slot_toggle_fullscreen()
+{
+    if( ! m_enable_menuslot ) return;
+
+    if( SESSION::is_full_win_main() ) m_win_main.unfullscreen();
+    else m_win_main.fullscreen();
+}
+
+
 //
 // messageビューをウィンドウ表示
 //
@@ -368,6 +390,15 @@ void Core::slot_toggle_embmsg()
 }
 
 
+//
+// messgeビューのwrap切り替え
+//
+void Core::slot_toggle_msg_wrap()
+{
+    CORE::core_set_command( "toggle_message_wrap", "" );
+}
+
+
 //
 // imageビュー表示設定
 //
@@ -544,18 +575,6 @@ void Core::slot_image_pref()
 }
 
 
-//
-// 過去ログ表示切替え
-//
-void Core::slot_toggle_oldarticle()
-{
-    CONFIG::set_show_oldarticle( ! CONFIG::get_show_oldarticle() );
-
-    SKELETON::MsgDiag mdiag( NULL, "次に開いた板から有効になります" );
-    mdiag.run();
-}
-
-
 //
 // 起動時にviewを復元
 //
@@ -1030,8 +1049,8 @@ void Core::slot_live_start_stop()
 //
 void Core::slot_search_cache_board()
 {
-    std::string url = BOARD::get_admin()->get_current_url();
-    if( ! url.empty() ) CORE::core_set_command( "open_article_searchlog", url );
+    const std::string url = BOARD::get_admin()->get_current_url();
+    if( ! url.empty() ) CORE::core_set_command( "open_article_searchlog", url, "", "noexec" );
 }
 
 
@@ -1040,7 +1059,7 @@ void Core::slot_search_cache_board()
 //
 void Core::slot_search_cache()
 {
-    CORE::core_set_command( "open_article_searchalllog" );
+    CORE::core_set_command( "open_article_searchlog", URL_SEARCH_ALLBOARD, "", "noexec" );
 }
 
 
@@ -1049,7 +1068,7 @@ void Core::slot_search_cache()
 //
 void Core::slot_show_cache_board()
 {
-    std::string url = DBTREE::url_subject( BOARD::get_admin()->get_current_url() );
+    const std::string url = DBTREE::url_subject( BOARD::get_admin()->get_current_url() );
     if( ! url.empty() ) CORE::core_set_command( "open_board_showlog", url );
 }
 
@@ -1068,7 +1087,7 @@ void Core::slot_show_cache()
 //
 void Core::slot_search_title()
 {
-    CORE::core_set_command( "open_article_searchtitle" );
+    CORE::core_set_command( "open_article_searchtitle", "", "", "noexec" );
 }
 
 
