@@ -10,9 +10,12 @@
 #include "skeleton/view.h"
 #include "skeleton/msgdiag.h"
 #include "skeleton/dragnote.h"
+#include "skeleton/editview.h"
 
 #include "dbtree/interface.h"
 
+#include "config/globalconf.h"
+
 #include "viewfactory.h"
 #include "command.h"
 #include "global.h"
@@ -37,7 +40,7 @@ using namespace MESSAGE;
 
 
 MessageAdmin::MessageAdmin( const std::string& url )
-    : SKELETON::Admin( url ), m_toolbar( NULL ), m_toolbar_preview( NULL )
+    : SKELETON::Admin( url ), m_toolbar( NULL ), m_toolbar_preview( NULL ), m_text_message( NULL )
 {
     get_notebook()->set_show_tabs( false );
 }
@@ -51,6 +54,7 @@ MessageAdmin::~MessageAdmin()
 
     if( m_toolbar ) delete m_toolbar;
     if( m_toolbar_preview ) delete m_toolbar_preview;
+    if( m_text_message ) delete m_text_message;
 }
 
 
@@ -69,6 +73,14 @@ std::string MessageAdmin::get_new_subject()
 }
 
 
+SKELETON::EditView* MessageAdmin::get_text_message()
+{
+    if( ! m_text_message ) m_text_message = new SKELETON::EditView();
+
+    return m_text_message;
+}
+
+
 //
 // ローカルコマンド実行
 //
@@ -82,9 +94,9 @@ void MessageAdmin::command_local( const COMMAND_ARGS& command )
     SKELETON::View *view = get_current_view();
 
     // 書き込みボタンにフォーカスを移す
-    if( command.command == "focus_writebutton" ){
-        if( get_notebook()->get_current_toolbar() == TOOLBAR_MESSAGE ) m_toolbar->focus_writebutton();
-        else m_toolbar_preview->focus_writebutton();
+    if( command.command == "focus_button_write" ){
+        if( get_notebook()->get_current_toolbar() == TOOLBAR_MESSAGE ) m_toolbar->focus_button_write();
+        else m_toolbar_preview->focus_button_write();
     }
     // プレビュー切り替え
     else if( command.command == "toggle_preview" ){
@@ -112,6 +124,21 @@ void MessageAdmin::command_local( const COMMAND_ARGS& command )
             m_toolbar_preview->set_active_previewbutton( true );
         }
     }
+    // 指定したスレに対応する書き込みビューを開いていて
+    // かつ書き込みビューが空なら閉じる
+    else if( command.command == "close_message" ){
+
+        SKELETON::View *view = get_current_view();
+        if( view && view->set_command( "empty" ) && view->get_url().find( command.url ) != std::string::npos ){
+            close_current_view();
+        }
+    }
+
+    // ビューの wrap 切り替え
+    else if( "toggle_wrap" ){
+
+        if( view ) view->set_command( command.command );
+    }
 }
 
 
@@ -199,7 +226,7 @@ void MessageAdmin::switch_admin()
 
 
 // virtual
-void MessageAdmin::tab_left()
+void MessageAdmin::tab_left( const bool updated )
 {
     SKELETON::View *view = get_current_view();
     if( view ) view->set_command( "tab_left" );
@@ -207,7 +234,7 @@ void MessageAdmin::tab_left()
 
 
 // virtual
-void MessageAdmin::tab_right()
+void MessageAdmin::tab_right( const bool updated )
 {
     SKELETON::View *view = get_current_view();
     if( view ) view->set_command( "tab_right" );
@@ -325,12 +352,12 @@ void MessageAdmin::show_toolbar()
         // 通常のツールバー
         m_toolbar = new MessageToolBar();
         get_notebook()->append_toolbar( *m_toolbar );
-        m_toolbar->show_toolbar();
+        m_toolbar->open_buttonbar();
 
         // プレビュー用のツールバー
         m_toolbar_preview = new MessageToolBarPreview();
         get_notebook()->append_toolbar( *m_toolbar_preview );
-        m_toolbar_preview->show_toolbar();
+        m_toolbar_preview->open_buttonbar();
     }
 
     get_notebook()->show_toolbar();
@@ -343,16 +370,20 @@ void MessageAdmin::show_toolbar()
 //
 // 破棄する場合はtrueが戻る
 //
-bool MessageAdmin::delete_message( SKELETON::View * view )
+const bool MessageAdmin::delete_message( SKELETON::View * view )
 {
-    SKELETON::MsgDiag mdiag( get_win(),
-                             "編集中のメッセージを閉じる前に内容を保存しますか？\n\n保存ボタンを押すとメッセージを保存できます。",
-                             false, Gtk::MESSAGE_WARNING, Gtk::BUTTONS_NONE );
+    if( ! CONFIG::get_show_savemsgdiag() ) return true;
+
+    SKELETON::MsgCheckDiag mdiag( get_win(),
+                                  "編集中のメッセージを閉じる前に内容を保存しますか？\n\n保存ボタンを押すとメッセージを保存できます。",
+
+                                  "今後表示しない(常に保存せずに閉じる) (_D)",
+                                  Gtk::MESSAGE_WARNING, Gtk::BUTTONS_NONE );
 
     mdiag.add_button( "保存せずに閉じる(_Q)", Gtk::RESPONSE_NO );
     mdiag.add_button( Gtk::Stock::CANCEL, Gtk::RESPONSE_CANCEL );
-    mdiag.add_button( Gtk::Stock::SAVE, Gtk::RESPONSE_YES );
-    mdiag.set_default_response( Gtk::RESPONSE_YES );
+    Gtk::Button button( Gtk::Stock::SAVE );
+    mdiag.add_default_button( &button, Gtk::RESPONSE_YES );
 
     int ret = mdiag.run();
     mdiag.hide();
@@ -362,6 +393,7 @@ bool MessageAdmin::delete_message( SKELETON::View * view )
     {
         case Gtk::RESPONSE_NO:
             result = true;
+            if( mdiag.get_chkbutton().get_active() ) CONFIG::set_show_savemsgdiag( false );
             break;
 
         case Gtk::RESPONSE_YES:
