@@ -4,7 +4,6 @@
 #define _MESSAGEVIEWBASE_H
 
 #include "skeleton/view.h"
-#include "skeleton/editview.h"
 #include "skeleton/imgbutton.h"
 #include "skeleton/compentry.h"
 #include "skeleton/jdtoolbar.h"
@@ -19,6 +18,7 @@ namespace SKELETON
 {
     class Admin;
     class LabelEntry;
+    class EditView;
 }
 
 
@@ -52,7 +52,7 @@ namespace MESSAGE
         SKELETON::CompletionEntry m_entry_name;
         SKELETON::CompletionEntry m_entry_mail;
 
-        SKELETON::EditView m_text_message;
+        SKELETON::EditView* m_text_message;
 
         bool m_enable_focus;
 
@@ -67,6 +67,11 @@ namespace MESSAGE
         int m_counter;
         std::string m_str_pass;
 
+        bool m_text_changed;
+
+        bool m_over_lines;
+        bool m_over_lng;
+
       public:
 
         MessageViewBase( const std::string& url );
@@ -76,6 +81,8 @@ namespace MESSAGE
         // SKELETON::View の関数のオーバロード
         //
 
+        virtual void save_session(){}
+
         // 親ウィンドウを取得
         virtual Gtk::Window* get_parent_win();
 
@@ -91,6 +98,12 @@ namespace MESSAGE
         // ロード中
         virtual const bool is_loading();
 
+        // 規制中や行数や文字列がオーバーして書き込めない
+        virtual const bool is_broken(){ return ( ! m_str_pass.empty() || m_over_lines || m_over_lng ); }
+
+        // キーを押した        
+        virtual const bool slot_key_press( GdkEventKey* event );
+
         virtual void clock_in();
         virtual void write();
         virtual void reload(){}
@@ -115,7 +128,7 @@ namespace MESSAGE
         void save_postlog();
 
         // 実際の書き込み処理を行う関数(子クラス別に実装)
-        virtual void write_impl() = 0;  
+        virtual void write_impl( const std::string& msg ) = 0;  
 
         // プレビュー切り替え
         void toggle_preview();
@@ -126,11 +139,11 @@ namespace MESSAGE
         // 下書きファイル挿入
         void insert_draft();
 
-        bool slot_key_press( GdkEventKey* event );
         bool slot_button_press( GdkEventButton* event );
         void slot_switch_page( GtkNotebookPage*, guint page );
+        void slot_text_changed();
 
-        virtual std::string create_message() = 0;
+        virtual const std::string create_message() = 0;
 
         void show_status();
 
@@ -139,12 +152,12 @@ namespace MESSAGE
         // Viewが所属するAdminクラス
         virtual SKELETON::Admin* get_admin();
 
-        void set_message( const std::string& msg ){ m_text_message.set_text( msg ); }
-        Glib::ustring get_message(){ return m_text_message.get_text(); }
+        void set_message( const std::string& msg );
+        const Glib::ustring get_message();
 
         SKELETON::CompletionEntry& get_entry_name(){ return m_entry_name; }
         SKELETON::CompletionEntry& get_entry_mail(){ return m_entry_mail; }
-        SKELETON::EditView& get_text_message() { return m_text_message; }
+        SKELETON::EditView* get_text_message() { return m_text_message; }
 
         void post_msg( const std::string& msg, bool new_article );
         void post_fin();
@@ -152,6 +165,9 @@ namespace MESSAGE
         void save_name();
         void setup_view();
         void pack_widget();
+
+        // テキストの折り返し
+        void set_wrap();
     };
 }
 
