@@ -39,7 +39,8 @@ enum
     OPEN_MODE_AUTO = 1,
     OPEN_MODE_NOSWITCH = 2,
     OPEN_MODE_LOCK = 4,
-    OPEN_MODE_OFFLINE = 8
+    OPEN_MODE_OFFLINE = 8,
+    OPEN_MODE_REGET = 16
 };
 
 
@@ -111,6 +112,17 @@ Admin::~Admin()
 }
 
 
+void Admin::save_session()
+{
+    std::list< SKELETON::View* > list_view = get_list_view();
+    std::list< SKELETON::View* >::iterator it = list_view.begin();
+    for( ; it != list_view.end(); ++it ){
+        SKELETON::View* view = ( *it );
+        if( view ) view->save_session();
+    }
+}
+
+
 //
 // メニューのセットアップ
 //
@@ -285,25 +297,6 @@ const bool Admin::is_booting()
 }
 
 
-// SIGHUPを受け取った
-void Admin::shutdown()
-{
-    int pages = m_notebook->get_n_pages();
-
-#ifdef _DEBUG
-    std::cout << "pages = " << pages << std::endl;
-#endif
-    if( pages ){
-
-        for( int i = 0; i < pages; ++i ){
-            SKELETON::View* view = dynamic_cast< View* >( m_notebook->get_nth_page( i ) );
-            if( view ) view->shutdown();
-        }
-    }
-}
-
-
-
 //
 // ページが含まれていないか
 //
@@ -374,9 +367,22 @@ void Admin::clock_in()
 void Admin::set_command( const std::string& command, const std::string& url,
                          const std::string& arg1, const std::string& arg2,
                          const std::string& arg3, const std::string& arg4,
-                         const std::string& arg5, const std::string& arg6 )
+                         const std::string& arg5, const std::string& arg6,
+                         const std::string& arg7, const std::string& arg8 )
 {
-    set_command_impl( false, command, url, arg1, arg2, arg3, arg4, arg5, arg6 );
+    COMMAND_ARGS command_arg;
+    command_arg.command = command;
+    command_arg.url = url;
+    command_arg.arg1 = arg1;
+    command_arg.arg2 = arg2;
+    command_arg.arg3 = arg3;
+    command_arg.arg4 = arg4;
+    command_arg.arg5 = arg5;
+    command_arg.arg6 = arg6;
+    command_arg.arg7 = arg7;
+    command_arg.arg8 = arg8;
+
+    set_command_impl( false, command_arg );
 }
 
 
@@ -384,11 +390,24 @@ void Admin::set_command( const std::string& command, const std::string& url,
 // コマンド受付(即実行)
 //
 void Admin::set_command_immediately( const std::string& command, const std::string& url,
-                         const std::string& arg1, const std::string& arg2,
-                         const std::string& arg3, const std::string& arg4,
-                         const std::string& arg5, const std::string& arg6 )
+                                     const std::string& arg1, const std::string& arg2,
+                                     const std::string& arg3, const std::string& arg4,
+                                     const std::string& arg5, const std::string& arg6,
+                                     const std::string& arg7, const std::string& arg8 )
 {
-    set_command_impl( true, command, url, arg1, arg2, arg3, arg4, arg5, arg6 );
+    COMMAND_ARGS command_arg;
+    command_arg.command = command;
+    command_arg.url = url;
+    command_arg.arg1 = arg1;
+    command_arg.arg2 = arg2;
+    command_arg.arg3 = arg3;
+    command_arg.arg4 = arg4;
+    command_arg.arg5 = arg5;
+    command_arg.arg6 = arg6;
+    command_arg.arg7 = arg7;
+    command_arg.arg8 = arg8;
+
+    set_command_impl( true, command_arg );
 }
 
 
@@ -401,11 +420,7 @@ void Admin::set_command_immediately( const std::string& command, const std::stri
 // immediately = false で呼び出して、緊急にコマンドを実行させたい場合は
 // immediately = true とすること。
 //
-void Admin::set_command_impl( const bool immediately,
-                         const std::string& command, const std::string& url,
-                         const std::string& arg1, const std::string& arg2,
-                         const std::string& arg3, const std::string& arg4,
-                         const std::string& arg5, const std::string& arg6 )
+void Admin::set_command_impl( const bool immediately, const COMMAND_ARGS& command_arg )
 {
 #ifdef _DEBUG
     std::cout << "Admin::set_command : immediately = " << immediately <<  " command = " << command << " url = " << url << std::endl
@@ -413,16 +428,6 @@ void Admin::set_command_impl( const bool immediately,
               << arg3 << " " << arg4 << std::endl
               << arg5 << " " << arg6 << std::endl;
 #endif
-    
-    COMMAND_ARGS command_arg;
-    command_arg.command = command;
-    command_arg.url = url;
-    command_arg.arg1 = arg1;
-    command_arg.arg2 = arg2;
-    command_arg.arg3 = arg3;
-    command_arg.arg4 = arg4;
-    command_arg.arg5 = arg5;
-    command_arg.arg6 = arg6;
 
     if( immediately ){
 
@@ -494,6 +499,9 @@ void Admin::exec_command()
     else if( command.command == "switch_view" ){
         switch_view( command.url );
     }
+    else if( command.command == "reload_view" ){
+        reload_view( command.url );
+    }
     else if( command.command == "tab_left" ){
         tab_left( false );
     }
@@ -543,13 +551,17 @@ void Admin::exec_command()
         unlock_all_view( command.url );
     }
 
+    // ビューを閉じる
     else if( command.command == "close_view" ){
-        if( command.arg1 == "closeall" ) close_all_view( command.url );
+        if( command.arg1 == "closeall" ) close_all_view( command.url );   // command.url を含むタブを全て閉じる
+        else if( command.arg1 == "closealltabs" ) slot_close_all_tabs();  // 全て閉じる
+        else if( command.arg1 == "closeother" ) close_other_views( command.url );
         else close_view( command.url );
     }
     else if( command.command == "close_currentview" ){
         close_current_view();
     }
+
     else if( command.command == "set_page" ){
         set_current_page( atoi( command.arg1.c_str() ) );
     }
@@ -587,17 +599,26 @@ void Admin::exec_command()
     // タイトル表示
     // アクティブなviewから依頼が来たらコアに渡す
     else if( command.command == "set_title" ){
-        set_title( command.url, command.arg1, false );
+
+        const bool force = ( command.arg2 == "force" );
+        set_title( command.url, command.arg1, force );
     }
 
     // ステータス表示
     // アクティブなviewから依頼が来たらコアに渡す
     else if( command.command == "set_status" ){
 
-        bool force = ( command.arg2 == "force" );
+        const bool force = ( command.arg2 == "force" );
         set_status( command.url, command.arg1, force );
     }
 
+    // ステータスの色を変える
+    else if( command.command == "set_status_color" ){
+
+        const bool force = ( command.arg2 == "force" );
+        set_status_color( command.url, command.arg1, force );
+    }
+
     // マウスジェスチャ
     else if( command.command  == "set_mginfo" ){
         if( m_win ) m_win->set_mginfo( command.arg1 );
@@ -608,6 +629,11 @@ void Admin::exec_command()
         reload_all_tabs();
     }
 
+    // 全タブ更新チェックして開く
+    else if( command.command == "check_update_reload_all_tabs" ){
+        check_update_all_tabs( true );
+    }
+
     // オートリロードのキャンセル
     else if( command.command == "cancel_reload" ){
         slot_cancel_reload_all_tabs();
@@ -778,6 +804,7 @@ void Admin::open_list( const COMMAND_ARGS& command_list )
         command_arg.arg1 = "true";   // タブで開く
         command_arg.arg2 = "false";  // 既に開いているかチェック
         command_arg.arg3 = "noswitch";  // タブを切り替えない
+        if( ! command_list.arg2.empty() ) command_arg.arg3 += " " + command_list.arg2;
 
 #ifdef _DEBUG
         std::cout << "url = " << command_arg.url << std::endl;
@@ -851,6 +878,7 @@ void Admin::update_status( View* view, const bool force )
         set_title( view->get_url(), view->get_title(), force );
         set_url( view->get_url(), view->url_for_copy(), force );
         set_status( view->get_url(), view->get_status(), force );
+        set_status_color( view->get_url(), view->get_color(), force );
     }
 }
 
@@ -869,7 +897,7 @@ void Admin::update_status( View* view, const bool force )
 //
 // command.arg2: "true" なら既に command.url を開いているかチェックしない
 //
-// command.arg3: モード
+// command.arg3: モード  ( 複数指定する場合は空白で空ける )
 //
 // "auto"なら表示されていればリロードせずに切替える
 // されていなければarg1で指定した場所に新しいタブで開いてロード
@@ -881,6 +909,8 @@ void Admin::update_status( View* view, const bool force )
 //
 // "offline" なら オフラインで開く
 //
+// "reget" なら読み込み時にキャッシュ等を消してから再読み込みする
+//
 //
 // その他のargは各ビュー別の設定
 //
@@ -905,6 +935,7 @@ void Admin::open_view( const COMMAND_ARGS& command )
         if( command.arg3.find( "noswitch" ) != std::string::npos ) mode |= OPEN_MODE_NOSWITCH;
         if( command.arg3.find( "lock" ) != std::string::npos ) mode |= OPEN_MODE_LOCK;
         if( command.arg3.find( "offline" ) != std::string::npos ) mode |= OPEN_MODE_OFFLINE;
+        if( command.arg3.find( "reget" ) != std::string::npos ) mode |= OPEN_MODE_REGET;
     }
 
     if( current_view ) current_view->focus_out();
@@ -935,6 +966,9 @@ void Admin::open_view( const COMMAND_ARGS& command )
             // オフラインで開く
             if( mode & OPEN_MODE_OFFLINE ) SESSION::set_online( false );
 
+            // ロード時にキャッシュを削除してからスレを再読み込みする
+            if( mode & OPEN_MODE_REGET ) view->set_reget( true );
+
             view->show_view();
             SESSION::set_online( online );
 
@@ -1007,10 +1041,22 @@ void Admin::open_view( const COMMAND_ARGS& command )
 
         if( current_view ){
 
-            std::string url_current = current_view->get_url();
+            const std::string url_current = current_view->get_url();
             delete current_view;
 
-            if( m_use_viewhistory ) HISTORY::get_history_manager()->append_viewhistory( url_current, view->get_url() );    
+            if( m_use_viewhistory ){
+
+                // Aを開く -> B をタブで開く -> A を閉じる -> A を開いて B と置き換える(*) -> B をタブで開く
+                // とすると、History_Manager::get_viewhistory()のキャッシュが誤作動して
+                // ビューの戻る進むが変になるので、(*)の所で進む戻るの履歴を引き継ぐのをキャンセルする
+                if( ! m_last_closed_url.empty() && view->get_url() == m_last_closed_url ){
+                    HISTORY::get_history_manager()->delete_viewhistory( m_last_closed_url );
+                    m_last_closed_url = std::string();
+                }
+
+                HISTORY::get_history_manager()->append_viewhistory( url_current, view->get_url() );    
+            }
+
         }
     }
 
@@ -1020,6 +1066,9 @@ void Admin::open_view( const COMMAND_ARGS& command )
     // オフラインで開く
     if( mode & OPEN_MODE_OFFLINE ) SESSION::set_online( false );
 
+    // ロード時にキャッシュを削除してからスレを再読み込みする
+    if( mode & OPEN_MODE_REGET ) view->set_reget( true );
+
     view->show_view();
     SESSION::set_online( online );
 
@@ -1082,6 +1131,15 @@ void Admin::switch_view( const std::string& url )
 }
 
 
+//
+// 指定したURLのビューを再読み込み
+//
+void Admin::reload_view( const std::string& url )
+{
+    SKELETON::View* view = get_view( url );
+    if( view ) view->reload();
+}
+
 
 //
 // タブ左移動
@@ -1391,6 +1449,18 @@ void Admin::close_all_view( const std::string& url )
 }
 
 
+//
+// url 以外のビューを全て閉じる
+//
+void Admin::close_other_views( const std::string& url )
+{
+    const int pages = m_notebook->get_n_pages();
+    for( int i = 0; i < pages; ++i ){
+        SKELETON::View* view = dynamic_cast< View* >( m_notebook->get_nth_page( i ) );
+        if( view && view->get_url() != url ) set_command( "close_view", view->get_url() );
+    }
+}
+
 
 //
 // 現在のビューを閉じる
@@ -1514,6 +1584,26 @@ void Admin::set_status( const std::string& url, const std::string& stat, const b
 }
 
 
+//
+// ステータスの色を変える
+//
+void Admin::set_status_color( const std::string& url, const std::string& color, const bool force )
+{
+    if( m_win ) m_win->set_status_color( color );
+    else{
+
+        SKELETON::View* view = get_current_view();
+        if( view ){
+            
+            // アクティブなviewからコマンドが来たら色を変える
+            if( force || ( m_focus && view->get_url() == url ) ){
+                CORE::core_set_command( "set_status_color", url, color );
+            }
+        }
+    }
+}
+
+
 //
 // フォーカスする
 //
@@ -2077,11 +2167,7 @@ void Admin::slot_close_other_tabs()
     SKELETON::View* view =  dynamic_cast< View* >( m_notebook->get_nth_page( m_clicked_page ) );
     if( view ) url = view->get_url();
 
-    int pages = m_notebook->get_n_pages();
-    for( int i = 0; i < pages; ++i ){
-        view = dynamic_cast< View* >( m_notebook->get_nth_page( i ) );
-        if( view && view->get_url() != url ) set_command( "close_view", view->get_url() );
-    }
+    close_other_views( url );
 }
 
 
@@ -2144,8 +2230,6 @@ void Admin::slot_close_all_tabs()
 void Admin::slot_check_update_all_tabs()
 {
     check_update_all_tabs( m_clicked_page, false );
-
-    CORE::get_checkupdate_manager()->run();
 }
 
 
@@ -2155,16 +2239,21 @@ void Admin::slot_check_update_all_tabs()
 void Admin::slot_check_update_reload_all_tabs()
 {
     check_update_all_tabs( m_clicked_page, true );
+}
 
-    CORE::get_checkupdate_manager()->run();
+
+//
+// 開いているタブから全てのタブの更新チェックと再読み込み
+//
+void Admin::check_update_all_tabs( const bool open )
+{
+    check_update_all_tabs( m_notebook->get_current_page(), open );
 }
 
 
 //
 // from_page から全てのタブを更新チェック
 //
-// この後で CORE::get_checkupdate_manager()->run() すること
-//
 void Admin::check_update_all_tabs( const int from_page, const bool open )
 {
 #ifdef _DEBUG
@@ -2175,17 +2264,19 @@ void Admin::check_update_all_tabs( const int from_page, const bool open )
 
     int pages = m_notebook->get_n_pages();
 
-    // クリックしたタブから右側
+    // 開始タブから右側
     for( int i = from_page ; i < pages; ++i ){
         SKELETON::View* view = dynamic_cast< View* >( m_notebook->get_nth_page( i ) );
         if( view && view->get_enable_autoreload() ) CORE::get_checkupdate_manager()->push_back( view->get_url(), open );
     }
 
-    // クリックしたタブから左側
+    // 開始タブから左側
     for( int i = 0 ; i < from_page; ++i ){
         SKELETON::View* view = dynamic_cast< View* >( m_notebook->get_nth_page( i ) );
         if( view && view->get_enable_autoreload() ) CORE::get_checkupdate_manager()->push_back( view->get_url(), open );
     }
+
+    CORE::get_checkupdate_manager()->run();
 }
 
 
@@ -2351,6 +2442,15 @@ void Admin::unlock( const int page )
     }
 }
 
+// urlで指定されるタブが存在するか
+const bool Admin::exist_tab( const std::string& url )
+{
+    SKELETON::View* view = get_view( url );
+    if( view ) return true;
+
+    return false;
+}
+
 // プロパティ表示
 void Admin::show_preference()
 {
@@ -2403,7 +2503,7 @@ void Admin::forward_clicked_viewhistory( const int count )
 //
 // 戻る、進む
 //
-bool Admin::back_forward_viewhistory( const std::string& url, const bool back, const int count )
+const bool Admin::back_forward_viewhistory( const std::string& url, const bool back, const int count )
 {
     if( ! m_use_viewhistory ) return false;
 
@@ -2460,9 +2560,7 @@ bool Admin::back_forward_viewhistory( const std::string& url, const bool back, c
                 return false;
             }
 
-            // 検索ビューなど、back/forwardしたときに view のurlが変わることがあるので
-            // view履歴内のURLを置き換える必要がある。そこで Admin::open_view() 中の
-            // append_viewhistory() を実行しないでここで View履歴の現在位置を変更する
+            // Admin::open_view() 中の append_viewhistory() を実行しないでここで View履歴の現在位置を変更する
             // Admin::Open_view()も参照すること
             const bool use_history = get_use_viewhistory();
             set_use_viewhistory( false );
@@ -2472,20 +2570,10 @@ bool Admin::back_forward_viewhistory( const std::string& url, const bool back, c
                 else HISTORY::get_history_manager()->forward_viewhistory( url, count, true );
             }
 
-            COMMAND_ARGS command_arg = url_to_openarg( historyitem->url, false, false );
+            const COMMAND_ARGS command_arg = url_to_openarg( historyitem->url, false, false );
             open_view( command_arg );
 
-            // URLが変わっていたらview履歴内のURLも更新
-            if( use_history ){
-
-                SKELETON::View* current_view = get_current_view();
-                if( current_view && current_view->get_url() != historyitem->url ){
-                    HISTORY::get_history_manager()->replace_current_url_viewhistory( historyitem->url, current_view->get_url() );
-                    redraw_toolbar();
-                }
-
-                set_use_viewhistory( true );
-            }
+            set_use_viewhistory( use_history );
 
             return true;
         }
