@@ -10,18 +10,14 @@
 
 #include "history/historymanager.h"
 
+#include "config/globalconf.h"
+
 #include "global.h"
 #include "session.h"
 #include "command.h"
 
 using namespace SKELETON;
 
-enum
-{
-    KEYJUMP_TIMEOUT = 1000
-};
-
-
 View::View( const std::string& url, const std::string& arg1 ,const std::string& arg2 )
     : m_url( url ),
       m_parent_win( NULL ),
@@ -35,27 +31,26 @@ View::View( const std::string& url, const std::string& arg1 ,const std::string&
       m_locked( false ),
       m_writeable( true ),
       m_id_toolbar( 0 ),
-      m_popup_upside( false )
+      m_popup_upside( false ),
+      m_reget( false )
 {}
 
 
 //
-// URL 変更
+// url_new に URL を変更
 //
-// update_history == true の時は 履歴も更新
-//
-void View::set_url( const std::string& url_new, const bool update_history )
+void View::set_url( const std::string& url_new )
 {
-    if( update_history && ! m_url.empty() && ! url_new.empty() && m_url != url_new ){
+    if( ! m_url.empty() && ! url_new.empty() && m_url != url_new ){
 
         // View履歴のURLを更新
         HISTORY::get_history_manager()->replace_url_viewhistory( m_url, url_new );
 
         // ツールバーのURLを更新
         get_admin()->set_command( "update_toolbar_url", m_url, url_new );
-    }
 
-    m_url = url_new;
+        m_url = url_new;
+    }
 }
 
 
@@ -75,7 +70,7 @@ void View::update_url( const std::string& url_old, const std::string& url_new )
     std::cout << m_url << " -> " << url << std::endl;
 #endif
 
-    set_url( url, true );
+    set_url( url );
 }
 
 
@@ -141,7 +136,7 @@ bool View::inc_keyjump_counter()
 
     ++m_keyjump_counter;
 
-    if( m_keyjump_counter > KEYJUMP_TIMEOUT / TIMER_TIMEOUT ) return true;
+    if( m_keyjump_counter > CONFIG::get_numberjmp_msec() / TIMER_TIMEOUT ) return true;
 
     return false;
 }
@@ -262,3 +257,15 @@ void View::slot_hide_popupmenu()
     // メニューを消したときにマウスポインタが領域外にあれば自分自身をhide
     if( ! is_mouse_on_view() ) sig_hide_popup().emit();
 }
+
+
+//
+// ラベルやステータスバーの色
+//
+const std::string View::get_color()
+{
+    if( is_broken() ) return "red";
+    else if( is_old() ) return "blue";
+
+    return "";
+}
