@@ -45,6 +45,7 @@ namespace SKELETON
         Gtk::HBox m_statbar;
         Gtk::Label m_label_stat;
         Gtk::EventBox m_label_stat_ebox;
+        Gtk::EventBox m_mginfo_ebox;
         Gtk::Tooltips m_tooltip;
 #endif
         Gtk::Label m_mginfo;
@@ -58,6 +59,11 @@ namespace SKELETON
 
         virtual void clock_in();
 
+        // 最大、最小化
+        void maximize_win();
+        void unmaximize_win();
+        void iconify_win();
+
         void set_spacing( int space );
 
         // hide 中
@@ -75,6 +81,9 @@ namespace SKELETON
         std::string get_status(){ return m_status; }
         void set_mginfo( const std::string& mginfo );
 
+        // ステータスの色を変える
+        void set_status_color( const std::string& color );
+
         // メインウィンドウに対して transient 設定
         void set_transient( bool set );
 
@@ -95,25 +104,28 @@ namespace SKELETON
 
         virtual const int get_x_win() = 0;
         virtual const int get_y_win() = 0;
-        virtual void set_x_win( int x ) = 0;
-        virtual void set_y_win( int y ) = 0;
+        virtual void set_x_win( const int x ) = 0;
+        virtual void set_y_win( const int y ) = 0;
 
         virtual const int get_width_win() = 0;
         virtual const int get_height_win() = 0;
-        virtual void set_width_win( int width ) = 0;
-        virtual void set_height_win( int height ) = 0;
+        virtual void set_width_win( const int width ) = 0;
+        virtual void set_height_win( const int height ) = 0;
 
         virtual const bool is_focus_win() = 0;
-        virtual void set_focus_win( bool set ) = 0;
+        virtual void set_focus_win( const bool set ) = 0;
 
         virtual const bool is_maximized_win() = 0;
-        virtual void set_maximized_win( bool set ) = 0;
+        virtual void set_maximized_win( const bool set ) = 0;
 
         virtual const bool is_iconified_win() = 0;
-        virtual void set_iconified_win( bool set ) = 0;
+        virtual void set_iconified_win( const bool set ) = 0;
+
+        virtual const bool is_full_win() = 0;
+        virtual void set_full_win( const bool set ) = 0;
 
         virtual const bool is_shown_win() = 0;
-        virtual void set_shown_win( bool set ) = 0;
+        virtual void set_shown_win( const bool set ) = 0;
 
         virtual bool on_focus_in_event( GdkEventFocus* event );
         virtual bool on_focus_out_event( GdkEventFocus* event );
@@ -124,9 +136,6 @@ namespace SKELETON
 
       private:
 
-        // 最大化する
-        void maximize_win();
-
         bool slot_idle();
 
         void move_win( const int x, const int y );
